# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlStats(object):
    """
    Sql Stats type object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlStats object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param sql_identifier:
            The value to assign to the sql_identifier property of this SqlStats.
        :type sql_identifier: str

        :param plan_hash_value:
            The value to assign to the plan_hash_value property of this SqlStats.
        :type plan_hash_value: int

        :param time_collected:
            The value to assign to the time_collected property of this SqlStats.
        :type time_collected: datetime

        :param instance_name:
            The value to assign to the instance_name property of this SqlStats.
        :type instance_name: str

        :param last_active_time:
            The value to assign to the last_active_time property of this SqlStats.
        :type last_active_time: str

        :param parse_calls:
            The value to assign to the parse_calls property of this SqlStats.
        :type parse_calls: int

        :param disk_reads:
            The value to assign to the disk_reads property of this SqlStats.
        :type disk_reads: int

        :param direct_reads:
            The value to assign to the direct_reads property of this SqlStats.
        :type direct_reads: int

        :param direct_writes:
            The value to assign to the direct_writes property of this SqlStats.
        :type direct_writes: int

        :param buffer_gets:
            The value to assign to the buffer_gets property of this SqlStats.
        :type buffer_gets: int

        :param rows_processed:
            The value to assign to the rows_processed property of this SqlStats.
        :type rows_processed: int

        :param serializable_aborts:
            The value to assign to the serializable_aborts property of this SqlStats.
        :type serializable_aborts: int

        :param fetches:
            The value to assign to the fetches property of this SqlStats.
        :type fetches: int

        :param executions:
            The value to assign to the executions property of this SqlStats.
        :type executions: int

        :param avoided_executions:
            The value to assign to the avoided_executions property of this SqlStats.
        :type avoided_executions: int

        :param end_of_fetch_count:
            The value to assign to the end_of_fetch_count property of this SqlStats.
        :type end_of_fetch_count: int

        :param loads:
            The value to assign to the loads property of this SqlStats.
        :type loads: int

        :param version_count:
            The value to assign to the version_count property of this SqlStats.
        :type version_count: int

        :param invalidations:
            The value to assign to the invalidations property of this SqlStats.
        :type invalidations: int

        :param obsolete_count:
            The value to assign to the obsolete_count property of this SqlStats.
        :type obsolete_count: int

        :param px_servers_executions:
            The value to assign to the px_servers_executions property of this SqlStats.
        :type px_servers_executions: int

        :param cpu_time_in_us:
            The value to assign to the cpu_time_in_us property of this SqlStats.
        :type cpu_time_in_us: int

        :param elapsed_time_in_us:
            The value to assign to the elapsed_time_in_us property of this SqlStats.
        :type elapsed_time_in_us: int

        :param avg_hard_parse_time_in_us:
            The value to assign to the avg_hard_parse_time_in_us property of this SqlStats.
        :type avg_hard_parse_time_in_us: int

        :param concurrency_wait_time_in_us:
            The value to assign to the concurrency_wait_time_in_us property of this SqlStats.
        :type concurrency_wait_time_in_us: int

        :param application_wait_time_in_us:
            The value to assign to the application_wait_time_in_us property of this SqlStats.
        :type application_wait_time_in_us: int

        :param cluster_wait_time_in_us:
            The value to assign to the cluster_wait_time_in_us property of this SqlStats.
        :type cluster_wait_time_in_us: int

        :param user_io_wait_time_in_us:
            The value to assign to the user_io_wait_time_in_us property of this SqlStats.
        :type user_io_wait_time_in_us: int

        :param plsql_exec_time_in_us:
            The value to assign to the plsql_exec_time_in_us property of this SqlStats.
        :type plsql_exec_time_in_us: int

        :param java_exec_time_in_us:
            The value to assign to the java_exec_time_in_us property of this SqlStats.
        :type java_exec_time_in_us: int

        :param sorts:
            The value to assign to the sorts property of this SqlStats.
        :type sorts: int

        :param sharable_mem:
            The value to assign to the sharable_mem property of this SqlStats.
        :type sharable_mem: int

        :param total_sharable_mem:
            The value to assign to the total_sharable_mem property of this SqlStats.
        :type total_sharable_mem: int

        :param type_check_mem:
            The value to assign to the type_check_mem property of this SqlStats.
        :type type_check_mem: int

        :param io_cell_offload_eligible_bytes:
            The value to assign to the io_cell_offload_eligible_bytes property of this SqlStats.
        :type io_cell_offload_eligible_bytes: int

        :param io_interconnect_bytes:
            The value to assign to the io_interconnect_bytes property of this SqlStats.
        :type io_interconnect_bytes: int

        :param physical_read_requests:
            The value to assign to the physical_read_requests property of this SqlStats.
        :type physical_read_requests: int

        :param physical_read_bytes:
            The value to assign to the physical_read_bytes property of this SqlStats.
        :type physical_read_bytes: int

        :param physical_write_requests:
            The value to assign to the physical_write_requests property of this SqlStats.
        :type physical_write_requests: int

        :param physical_write_bytes:
            The value to assign to the physical_write_bytes property of this SqlStats.
        :type physical_write_bytes: int

        :param exact_matching_signature:
            The value to assign to the exact_matching_signature property of this SqlStats.
        :type exact_matching_signature: str

        :param force_matching_signature:
            The value to assign to the force_matching_signature property of this SqlStats.
        :type force_matching_signature: str

        :param io_cell_uncompressed_bytes:
            The value to assign to the io_cell_uncompressed_bytes property of this SqlStats.
        :type io_cell_uncompressed_bytes: int

        :param io_cell_offload_returned_bytes:
            The value to assign to the io_cell_offload_returned_bytes property of this SqlStats.
        :type io_cell_offload_returned_bytes: int

        :param child_number:
            The value to assign to the child_number property of this SqlStats.
        :type child_number: int

        :param command_type:
            The value to assign to the command_type property of this SqlStats.
        :type command_type: int

        :param users_opening:
            The value to assign to the users_opening property of this SqlStats.
        :type users_opening: int

        :param users_executing:
            The value to assign to the users_executing property of this SqlStats.
        :type users_executing: int

        :param optimizer_cost:
            The value to assign to the optimizer_cost property of this SqlStats.
        :type optimizer_cost: int

        :param full_plan_hash_value:
            The value to assign to the full_plan_hash_value property of this SqlStats.
        :type full_plan_hash_value: str

        :param module:
            The value to assign to the module property of this SqlStats.
        :type module: str

        :param service:
            The value to assign to the service property of this SqlStats.
        :type service: str

        :param action:
            The value to assign to the action property of this SqlStats.
        :type action: str

        :param sql_profile:
            The value to assign to the sql_profile property of this SqlStats.
        :type sql_profile: str

        :param sql_patch:
            The value to assign to the sql_patch property of this SqlStats.
        :type sql_patch: str

        :param sql_plan_baseline:
            The value to assign to the sql_plan_baseline property of this SqlStats.
        :type sql_plan_baseline: str

        :param delta_execution_count:
            The value to assign to the delta_execution_count property of this SqlStats.
        :type delta_execution_count: int

        :param delta_cpu_time:
            The value to assign to the delta_cpu_time property of this SqlStats.
        :type delta_cpu_time: int

        :param delta_io_bytes:
            The value to assign to the delta_io_bytes property of this SqlStats.
        :type delta_io_bytes: int

        :param delta_cpu_rank:
            The value to assign to the delta_cpu_rank property of this SqlStats.
        :type delta_cpu_rank: int

        :param delta_execs_rank:
            The value to assign to the delta_execs_rank property of this SqlStats.
        :type delta_execs_rank: int

        :param sharable_mem_rank:
            The value to assign to the sharable_mem_rank property of this SqlStats.
        :type sharable_mem_rank: int

        :param delta_io_rank:
            The value to assign to the delta_io_rank property of this SqlStats.
        :type delta_io_rank: int

        :param harmonic_sum:
            The value to assign to the harmonic_sum property of this SqlStats.
        :type harmonic_sum: int

        :param wt_harmonic_sum:
            The value to assign to the wt_harmonic_sum property of this SqlStats.
        :type wt_harmonic_sum: int

        :param total_sql_count:
            The value to assign to the total_sql_count property of this SqlStats.
        :type total_sql_count: int

        """
        self.swagger_types = {
            'sql_identifier': 'str',
            'plan_hash_value': 'int',
            'time_collected': 'datetime',
            'instance_name': 'str',
            'last_active_time': 'str',
            'parse_calls': 'int',
            'disk_reads': 'int',
            'direct_reads': 'int',
            'direct_writes': 'int',
            'buffer_gets': 'int',
            'rows_processed': 'int',
            'serializable_aborts': 'int',
            'fetches': 'int',
            'executions': 'int',
            'avoided_executions': 'int',
            'end_of_fetch_count': 'int',
            'loads': 'int',
            'version_count': 'int',
            'invalidations': 'int',
            'obsolete_count': 'int',
            'px_servers_executions': 'int',
            'cpu_time_in_us': 'int',
            'elapsed_time_in_us': 'int',
            'avg_hard_parse_time_in_us': 'int',
            'concurrency_wait_time_in_us': 'int',
            'application_wait_time_in_us': 'int',
            'cluster_wait_time_in_us': 'int',
            'user_io_wait_time_in_us': 'int',
            'plsql_exec_time_in_us': 'int',
            'java_exec_time_in_us': 'int',
            'sorts': 'int',
            'sharable_mem': 'int',
            'total_sharable_mem': 'int',
            'type_check_mem': 'int',
            'io_cell_offload_eligible_bytes': 'int',
            'io_interconnect_bytes': 'int',
            'physical_read_requests': 'int',
            'physical_read_bytes': 'int',
            'physical_write_requests': 'int',
            'physical_write_bytes': 'int',
            'exact_matching_signature': 'str',
            'force_matching_signature': 'str',
            'io_cell_uncompressed_bytes': 'int',
            'io_cell_offload_returned_bytes': 'int',
            'child_number': 'int',
            'command_type': 'int',
            'users_opening': 'int',
            'users_executing': 'int',
            'optimizer_cost': 'int',
            'full_plan_hash_value': 'str',
            'module': 'str',
            'service': 'str',
            'action': 'str',
            'sql_profile': 'str',
            'sql_patch': 'str',
            'sql_plan_baseline': 'str',
            'delta_execution_count': 'int',
            'delta_cpu_time': 'int',
            'delta_io_bytes': 'int',
            'delta_cpu_rank': 'int',
            'delta_execs_rank': 'int',
            'sharable_mem_rank': 'int',
            'delta_io_rank': 'int',
            'harmonic_sum': 'int',
            'wt_harmonic_sum': 'int',
            'total_sql_count': 'int'
        }

        self.attribute_map = {
            'sql_identifier': 'sqlIdentifier',
            'plan_hash_value': 'planHashValue',
            'time_collected': 'timeCollected',
            'instance_name': 'instanceName',
            'last_active_time': 'lastActiveTime',
            'parse_calls': 'parseCalls',
            'disk_reads': 'diskReads',
            'direct_reads': 'directReads',
            'direct_writes': 'directWrites',
            'buffer_gets': 'bufferGets',
            'rows_processed': 'rowsProcessed',
            'serializable_aborts': 'serializableAborts',
            'fetches': 'fetches',
            'executions': 'executions',
            'avoided_executions': 'avoidedExecutions',
            'end_of_fetch_count': 'endOfFetchCount',
            'loads': 'loads',
            'version_count': 'versionCount',
            'invalidations': 'invalidations',
            'obsolete_count': 'obsoleteCount',
            'px_servers_executions': 'pxServersExecutions',
            'cpu_time_in_us': 'cpuTimeInUs',
            'elapsed_time_in_us': 'elapsedTimeInUs',
            'avg_hard_parse_time_in_us': 'avgHardParseTimeInUs',
            'concurrency_wait_time_in_us': 'concurrencyWaitTimeInUs',
            'application_wait_time_in_us': 'applicationWaitTimeInUs',
            'cluster_wait_time_in_us': 'clusterWaitTimeInUs',
            'user_io_wait_time_in_us': 'userIoWaitTimeInUs',
            'plsql_exec_time_in_us': 'plsqlExecTimeInUs',
            'java_exec_time_in_us': 'javaExecTimeInUs',
            'sorts': 'sorts',
            'sharable_mem': 'sharableMem',
            'total_sharable_mem': 'totalSharableMem',
            'type_check_mem': 'typeCheckMem',
            'io_cell_offload_eligible_bytes': 'ioCellOffloadEligibleBytes',
            'io_interconnect_bytes': 'ioInterconnectBytes',
            'physical_read_requests': 'physicalReadRequests',
            'physical_read_bytes': 'physicalReadBytes',
            'physical_write_requests': 'physicalWriteRequests',
            'physical_write_bytes': 'physicalWriteBytes',
            'exact_matching_signature': 'exactMatchingSignature',
            'force_matching_signature': 'forceMatchingSignature',
            'io_cell_uncompressed_bytes': 'ioCellUncompressedBytes',
            'io_cell_offload_returned_bytes': 'ioCellOffloadReturnedBytes',
            'child_number': 'childNumber',
            'command_type': 'commandType',
            'users_opening': 'usersOpening',
            'users_executing': 'usersExecuting',
            'optimizer_cost': 'optimizerCost',
            'full_plan_hash_value': 'fullPlanHashValue',
            'module': 'module',
            'service': 'service',
            'action': 'action',
            'sql_profile': 'sqlProfile',
            'sql_patch': 'sqlPatch',
            'sql_plan_baseline': 'sqlPlanBaseline',
            'delta_execution_count': 'deltaExecutionCount',
            'delta_cpu_time': 'deltaCpuTime',
            'delta_io_bytes': 'deltaIoBytes',
            'delta_cpu_rank': 'deltaCpuRank',
            'delta_execs_rank': 'deltaExecsRank',
            'sharable_mem_rank': 'sharableMemRank',
            'delta_io_rank': 'deltaIoRank',
            'harmonic_sum': 'harmonicSum',
            'wt_harmonic_sum': 'wtHarmonicSum',
            'total_sql_count': 'totalSqlCount'
        }

        self._sql_identifier = None
        self._plan_hash_value = None
        self._time_collected = None
        self._instance_name = None
        self._last_active_time = None
        self._parse_calls = None
        self._disk_reads = None
        self._direct_reads = None
        self._direct_writes = None
        self._buffer_gets = None
        self._rows_processed = None
        self._serializable_aborts = None
        self._fetches = None
        self._executions = None
        self._avoided_executions = None
        self._end_of_fetch_count = None
        self._loads = None
        self._version_count = None
        self._invalidations = None
        self._obsolete_count = None
        self._px_servers_executions = None
        self._cpu_time_in_us = None
        self._elapsed_time_in_us = None
        self._avg_hard_parse_time_in_us = None
        self._concurrency_wait_time_in_us = None
        self._application_wait_time_in_us = None
        self._cluster_wait_time_in_us = None
        self._user_io_wait_time_in_us = None
        self._plsql_exec_time_in_us = None
        self._java_exec_time_in_us = None
        self._sorts = None
        self._sharable_mem = None
        self._total_sharable_mem = None
        self._type_check_mem = None
        self._io_cell_offload_eligible_bytes = None
        self._io_interconnect_bytes = None
        self._physical_read_requests = None
        self._physical_read_bytes = None
        self._physical_write_requests = None
        self._physical_write_bytes = None
        self._exact_matching_signature = None
        self._force_matching_signature = None
        self._io_cell_uncompressed_bytes = None
        self._io_cell_offload_returned_bytes = None
        self._child_number = None
        self._command_type = None
        self._users_opening = None
        self._users_executing = None
        self._optimizer_cost = None
        self._full_plan_hash_value = None
        self._module = None
        self._service = None
        self._action = None
        self._sql_profile = None
        self._sql_patch = None
        self._sql_plan_baseline = None
        self._delta_execution_count = None
        self._delta_cpu_time = None
        self._delta_io_bytes = None
        self._delta_cpu_rank = None
        self._delta_execs_rank = None
        self._sharable_mem_rank = None
        self._delta_io_rank = None
        self._harmonic_sum = None
        self._wt_harmonic_sum = None
        self._total_sql_count = None

    @property
    def sql_identifier(self):
        """
        **[Required]** Gets the sql_identifier of this SqlStats.
        Unique SQL_ID for a SQL Statement.


        :return: The sql_identifier of this SqlStats.
        :rtype: str
        """
        return self._sql_identifier

    @sql_identifier.setter
    def sql_identifier(self, sql_identifier):
        """
        Sets the sql_identifier of this SqlStats.
        Unique SQL_ID for a SQL Statement.


        :param sql_identifier: The sql_identifier of this SqlStats.
        :type: str
        """
        self._sql_identifier = sql_identifier

    @property
    def plan_hash_value(self):
        """
        **[Required]** Gets the plan_hash_value of this SqlStats.
        Plan hash value for the SQL Execution Plan


        :return: The plan_hash_value of this SqlStats.
        :rtype: int
        """
        return self._plan_hash_value

    @plan_hash_value.setter
    def plan_hash_value(self, plan_hash_value):
        """
        Sets the plan_hash_value of this SqlStats.
        Plan hash value for the SQL Execution Plan


        :param plan_hash_value: The plan_hash_value of this SqlStats.
        :type: int
        """
        self._plan_hash_value = plan_hash_value

    @property
    def time_collected(self):
        """
        **[Required]** Gets the time_collected of this SqlStats.
        Collection timestamp
        Example: `\"2020-03-31T00:00:00.000Z\"`


        :return: The time_collected of this SqlStats.
        :rtype: datetime
        """
        return self._time_collected

    @time_collected.setter
    def time_collected(self, time_collected):
        """
        Sets the time_collected of this SqlStats.
        Collection timestamp
        Example: `\"2020-03-31T00:00:00.000Z\"`


        :param time_collected: The time_collected of this SqlStats.
        :type: datetime
        """
        self._time_collected = time_collected

    @property
    def instance_name(self):
        """
        **[Required]** Gets the instance_name of this SqlStats.
        Name of Database Instance
        Example: `\"DB10902_1\"`


        :return: The instance_name of this SqlStats.
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """
        Sets the instance_name of this SqlStats.
        Name of Database Instance
        Example: `\"DB10902_1\"`


        :param instance_name: The instance_name of this SqlStats.
        :type: str
        """
        self._instance_name = instance_name

    @property
    def last_active_time(self):
        """
        Gets the last_active_time of this SqlStats.
        last_active_time
        Example: `\"0000000099CCE300\"`


        :return: The last_active_time of this SqlStats.
        :rtype: str
        """
        return self._last_active_time

    @last_active_time.setter
    def last_active_time(self, last_active_time):
        """
        Sets the last_active_time of this SqlStats.
        last_active_time
        Example: `\"0000000099CCE300\"`


        :param last_active_time: The last_active_time of this SqlStats.
        :type: str
        """
        self._last_active_time = last_active_time

    @property
    def parse_calls(self):
        """
        Gets the parse_calls of this SqlStats.
        Total integer of parse calls
         Example: `60`


        :return: The parse_calls of this SqlStats.
        :rtype: int
        """
        return self._parse_calls

    @parse_calls.setter
    def parse_calls(self, parse_calls):
        """
        Sets the parse_calls of this SqlStats.
        Total integer of parse calls
         Example: `60`


        :param parse_calls: The parse_calls of this SqlStats.
        :type: int
        """
        self._parse_calls = parse_calls

    @property
    def disk_reads(self):
        """
        Gets the disk_reads of this SqlStats.
        Number of disk reads


        :return: The disk_reads of this SqlStats.
        :rtype: int
        """
        return self._disk_reads

    @disk_reads.setter
    def disk_reads(self, disk_reads):
        """
        Sets the disk_reads of this SqlStats.
        Number of disk reads


        :param disk_reads: The disk_reads of this SqlStats.
        :type: int
        """
        self._disk_reads = disk_reads

    @property
    def direct_reads(self):
        """
        Gets the direct_reads of this SqlStats.
        Number of direct reads


        :return: The direct_reads of this SqlStats.
        :rtype: int
        """
        return self._direct_reads

    @direct_reads.setter
    def direct_reads(self, direct_reads):
        """
        Sets the direct_reads of this SqlStats.
        Number of direct reads


        :param direct_reads: The direct_reads of this SqlStats.
        :type: int
        """
        self._direct_reads = direct_reads

    @property
    def direct_writes(self):
        """
        Gets the direct_writes of this SqlStats.
        Number of Direct writes


        :return: The direct_writes of this SqlStats.
        :rtype: int
        """
        return self._direct_writes

    @direct_writes.setter
    def direct_writes(self, direct_writes):
        """
        Sets the direct_writes of this SqlStats.
        Number of Direct writes


        :param direct_writes: The direct_writes of this SqlStats.
        :type: int
        """
        self._direct_writes = direct_writes

    @property
    def buffer_gets(self):
        """
        Gets the buffer_gets of this SqlStats.
        Number of Buffer Gets


        :return: The buffer_gets of this SqlStats.
        :rtype: int
        """
        return self._buffer_gets

    @buffer_gets.setter
    def buffer_gets(self, buffer_gets):
        """
        Sets the buffer_gets of this SqlStats.
        Number of Buffer Gets


        :param buffer_gets: The buffer_gets of this SqlStats.
        :type: int
        """
        self._buffer_gets = buffer_gets

    @property
    def rows_processed(self):
        """
        Gets the rows_processed of this SqlStats.
        Number of row processed


        :return: The rows_processed of this SqlStats.
        :rtype: int
        """
        return self._rows_processed

    @rows_processed.setter
    def rows_processed(self, rows_processed):
        """
        Sets the rows_processed of this SqlStats.
        Number of row processed


        :param rows_processed: The rows_processed of this SqlStats.
        :type: int
        """
        self._rows_processed = rows_processed

    @property
    def serializable_aborts(self):
        """
        Gets the serializable_aborts of this SqlStats.
        Number of serializable aborts


        :return: The serializable_aborts of this SqlStats.
        :rtype: int
        """
        return self._serializable_aborts

    @serializable_aborts.setter
    def serializable_aborts(self, serializable_aborts):
        """
        Sets the serializable_aborts of this SqlStats.
        Number of serializable aborts


        :param serializable_aborts: The serializable_aborts of this SqlStats.
        :type: int
        """
        self._serializable_aborts = serializable_aborts

    @property
    def fetches(self):
        """
        Gets the fetches of this SqlStats.
        Number of fetches


        :return: The fetches of this SqlStats.
        :rtype: int
        """
        return self._fetches

    @fetches.setter
    def fetches(self, fetches):
        """
        Sets the fetches of this SqlStats.
        Number of fetches


        :param fetches: The fetches of this SqlStats.
        :type: int
        """
        self._fetches = fetches

    @property
    def executions(self):
        """
        Gets the executions of this SqlStats.
        Number of executions


        :return: The executions of this SqlStats.
        :rtype: int
        """
        return self._executions

    @executions.setter
    def executions(self, executions):
        """
        Sets the executions of this SqlStats.
        Number of executions


        :param executions: The executions of this SqlStats.
        :type: int
        """
        self._executions = executions

    @property
    def avoided_executions(self):
        """
        Gets the avoided_executions of this SqlStats.
        Number of executions attempted on this object, but prevented due to the SQL statement being in quarantine


        :return: The avoided_executions of this SqlStats.
        :rtype: int
        """
        return self._avoided_executions

    @avoided_executions.setter
    def avoided_executions(self, avoided_executions):
        """
        Sets the avoided_executions of this SqlStats.
        Number of executions attempted on this object, but prevented due to the SQL statement being in quarantine


        :param avoided_executions: The avoided_executions of this SqlStats.
        :type: int
        """
        self._avoided_executions = avoided_executions

    @property
    def end_of_fetch_count(self):
        """
        Gets the end_of_fetch_count of this SqlStats.
        Number of times this cursor was fully executed since the cursor was brought into the library cache


        :return: The end_of_fetch_count of this SqlStats.
        :rtype: int
        """
        return self._end_of_fetch_count

    @end_of_fetch_count.setter
    def end_of_fetch_count(self, end_of_fetch_count):
        """
        Sets the end_of_fetch_count of this SqlStats.
        Number of times this cursor was fully executed since the cursor was brought into the library cache


        :param end_of_fetch_count: The end_of_fetch_count of this SqlStats.
        :type: int
        """
        self._end_of_fetch_count = end_of_fetch_count

    @property
    def loads(self):
        """
        Gets the loads of this SqlStats.
        Number of times the object was either loaded or reloaded


        :return: The loads of this SqlStats.
        :rtype: int
        """
        return self._loads

    @loads.setter
    def loads(self, loads):
        """
        Sets the loads of this SqlStats.
        Number of times the object was either loaded or reloaded


        :param loads: The loads of this SqlStats.
        :type: int
        """
        self._loads = loads

    @property
    def version_count(self):
        """
        Gets the version_count of this SqlStats.
        Number of cursors present in the cache with this SQL text and plan


        :return: The version_count of this SqlStats.
        :rtype: int
        """
        return self._version_count

    @version_count.setter
    def version_count(self, version_count):
        """
        Sets the version_count of this SqlStats.
        Number of cursors present in the cache with this SQL text and plan


        :param version_count: The version_count of this SqlStats.
        :type: int
        """
        self._version_count = version_count

    @property
    def invalidations(self):
        """
        Gets the invalidations of this SqlStats.
        Number of times this child cursor has been invalidated


        :return: The invalidations of this SqlStats.
        :rtype: int
        """
        return self._invalidations

    @invalidations.setter
    def invalidations(self, invalidations):
        """
        Sets the invalidations of this SqlStats.
        Number of times this child cursor has been invalidated


        :param invalidations: The invalidations of this SqlStats.
        :type: int
        """
        self._invalidations = invalidations

    @property
    def obsolete_count(self):
        """
        Gets the obsolete_count of this SqlStats.
        Number of times that a parent cursor became obsolete


        :return: The obsolete_count of this SqlStats.
        :rtype: int
        """
        return self._obsolete_count

    @obsolete_count.setter
    def obsolete_count(self, obsolete_count):
        """
        Sets the obsolete_count of this SqlStats.
        Number of times that a parent cursor became obsolete


        :param obsolete_count: The obsolete_count of this SqlStats.
        :type: int
        """
        self._obsolete_count = obsolete_count

    @property
    def px_servers_executions(self):
        """
        Gets the px_servers_executions of this SqlStats.
        Total number of executions performed by parallel execution servers (0 when the statement has never been executed in parallel)


        :return: The px_servers_executions of this SqlStats.
        :rtype: int
        """
        return self._px_servers_executions

    @px_servers_executions.setter
    def px_servers_executions(self, px_servers_executions):
        """
        Sets the px_servers_executions of this SqlStats.
        Total number of executions performed by parallel execution servers (0 when the statement has never been executed in parallel)


        :param px_servers_executions: The px_servers_executions of this SqlStats.
        :type: int
        """
        self._px_servers_executions = px_servers_executions

    @property
    def cpu_time_in_us(self):
        """
        Gets the cpu_time_in_us of this SqlStats.
        CPU time (in microseconds) used by this cursor for parsing, executing, and fetching


        :return: The cpu_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._cpu_time_in_us

    @cpu_time_in_us.setter
    def cpu_time_in_us(self, cpu_time_in_us):
        """
        Sets the cpu_time_in_us of this SqlStats.
        CPU time (in microseconds) used by this cursor for parsing, executing, and fetching


        :param cpu_time_in_us: The cpu_time_in_us of this SqlStats.
        :type: int
        """
        self._cpu_time_in_us = cpu_time_in_us

    @property
    def elapsed_time_in_us(self):
        """
        Gets the elapsed_time_in_us of this SqlStats.
        Elapsed time (in microseconds) used by this cursor for parsing, executing, and fetching.


        :return: The elapsed_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._elapsed_time_in_us

    @elapsed_time_in_us.setter
    def elapsed_time_in_us(self, elapsed_time_in_us):
        """
        Sets the elapsed_time_in_us of this SqlStats.
        Elapsed time (in microseconds) used by this cursor for parsing, executing, and fetching.


        :param elapsed_time_in_us: The elapsed_time_in_us of this SqlStats.
        :type: int
        """
        self._elapsed_time_in_us = elapsed_time_in_us

    @property
    def avg_hard_parse_time_in_us(self):
        """
        Gets the avg_hard_parse_time_in_us of this SqlStats.
        Average hard parse time (in microseconds) used by this cursor


        :return: The avg_hard_parse_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._avg_hard_parse_time_in_us

    @avg_hard_parse_time_in_us.setter
    def avg_hard_parse_time_in_us(self, avg_hard_parse_time_in_us):
        """
        Sets the avg_hard_parse_time_in_us of this SqlStats.
        Average hard parse time (in microseconds) used by this cursor


        :param avg_hard_parse_time_in_us: The avg_hard_parse_time_in_us of this SqlStats.
        :type: int
        """
        self._avg_hard_parse_time_in_us = avg_hard_parse_time_in_us

    @property
    def concurrency_wait_time_in_us(self):
        """
        Gets the concurrency_wait_time_in_us of this SqlStats.
        Concurrency wait time (in microseconds)


        :return: The concurrency_wait_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._concurrency_wait_time_in_us

    @concurrency_wait_time_in_us.setter
    def concurrency_wait_time_in_us(self, concurrency_wait_time_in_us):
        """
        Sets the concurrency_wait_time_in_us of this SqlStats.
        Concurrency wait time (in microseconds)


        :param concurrency_wait_time_in_us: The concurrency_wait_time_in_us of this SqlStats.
        :type: int
        """
        self._concurrency_wait_time_in_us = concurrency_wait_time_in_us

    @property
    def application_wait_time_in_us(self):
        """
        Gets the application_wait_time_in_us of this SqlStats.
        Application wait time (in microseconds)


        :return: The application_wait_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._application_wait_time_in_us

    @application_wait_time_in_us.setter
    def application_wait_time_in_us(self, application_wait_time_in_us):
        """
        Sets the application_wait_time_in_us of this SqlStats.
        Application wait time (in microseconds)


        :param application_wait_time_in_us: The application_wait_time_in_us of this SqlStats.
        :type: int
        """
        self._application_wait_time_in_us = application_wait_time_in_us

    @property
    def cluster_wait_time_in_us(self):
        """
        Gets the cluster_wait_time_in_us of this SqlStats.
        Cluster wait time (in microseconds). This value is specific to Oracle RAC


        :return: The cluster_wait_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._cluster_wait_time_in_us

    @cluster_wait_time_in_us.setter
    def cluster_wait_time_in_us(self, cluster_wait_time_in_us):
        """
        Sets the cluster_wait_time_in_us of this SqlStats.
        Cluster wait time (in microseconds). This value is specific to Oracle RAC


        :param cluster_wait_time_in_us: The cluster_wait_time_in_us of this SqlStats.
        :type: int
        """
        self._cluster_wait_time_in_us = cluster_wait_time_in_us

    @property
    def user_io_wait_time_in_us(self):
        """
        Gets the user_io_wait_time_in_us of this SqlStats.
        User I/O wait time (in microseconds)


        :return: The user_io_wait_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._user_io_wait_time_in_us

    @user_io_wait_time_in_us.setter
    def user_io_wait_time_in_us(self, user_io_wait_time_in_us):
        """
        Sets the user_io_wait_time_in_us of this SqlStats.
        User I/O wait time (in microseconds)


        :param user_io_wait_time_in_us: The user_io_wait_time_in_us of this SqlStats.
        :type: int
        """
        self._user_io_wait_time_in_us = user_io_wait_time_in_us

    @property
    def plsql_exec_time_in_us(self):
        """
        Gets the plsql_exec_time_in_us of this SqlStats.
        PL/SQL execution time (in microseconds)


        :return: The plsql_exec_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._plsql_exec_time_in_us

    @plsql_exec_time_in_us.setter
    def plsql_exec_time_in_us(self, plsql_exec_time_in_us):
        """
        Sets the plsql_exec_time_in_us of this SqlStats.
        PL/SQL execution time (in microseconds)


        :param plsql_exec_time_in_us: The plsql_exec_time_in_us of this SqlStats.
        :type: int
        """
        self._plsql_exec_time_in_us = plsql_exec_time_in_us

    @property
    def java_exec_time_in_us(self):
        """
        Gets the java_exec_time_in_us of this SqlStats.
        Java execution time (in microseconds)


        :return: The java_exec_time_in_us of this SqlStats.
        :rtype: int
        """
        return self._java_exec_time_in_us

    @java_exec_time_in_us.setter
    def java_exec_time_in_us(self, java_exec_time_in_us):
        """
        Sets the java_exec_time_in_us of this SqlStats.
        Java execution time (in microseconds)


        :param java_exec_time_in_us: The java_exec_time_in_us of this SqlStats.
        :type: int
        """
        self._java_exec_time_in_us = java_exec_time_in_us

    @property
    def sorts(self):
        """
        Gets the sorts of this SqlStats.
        Number of sorts that were done for the child cursor


        :return: The sorts of this SqlStats.
        :rtype: int
        """
        return self._sorts

    @sorts.setter
    def sorts(self, sorts):
        """
        Sets the sorts of this SqlStats.
        Number of sorts that were done for the child cursor


        :param sorts: The sorts of this SqlStats.
        :type: int
        """
        self._sorts = sorts

    @property
    def sharable_mem(self):
        """
        Gets the sharable_mem of this SqlStats.
        Total shared memory (in bytes) currently occupied by all cursors with this SQL text and plan


        :return: The sharable_mem of this SqlStats.
        :rtype: int
        """
        return self._sharable_mem

    @sharable_mem.setter
    def sharable_mem(self, sharable_mem):
        """
        Sets the sharable_mem of this SqlStats.
        Total shared memory (in bytes) currently occupied by all cursors with this SQL text and plan


        :param sharable_mem: The sharable_mem of this SqlStats.
        :type: int
        """
        self._sharable_mem = sharable_mem

    @property
    def total_sharable_mem(self):
        """
        Gets the total_sharable_mem of this SqlStats.
        Total shared memory (in bytes) occupied by all cursors with this SQL text and plan if they were to be fully loaded in the shared pool (that is, cursor size)


        :return: The total_sharable_mem of this SqlStats.
        :rtype: int
        """
        return self._total_sharable_mem

    @total_sharable_mem.setter
    def total_sharable_mem(self, total_sharable_mem):
        """
        Sets the total_sharable_mem of this SqlStats.
        Total shared memory (in bytes) occupied by all cursors with this SQL text and plan if they were to be fully loaded in the shared pool (that is, cursor size)


        :param total_sharable_mem: The total_sharable_mem of this SqlStats.
        :type: int
        """
        self._total_sharable_mem = total_sharable_mem

    @property
    def type_check_mem(self):
        """
        Gets the type_check_mem of this SqlStats.
        Typecheck memory


        :return: The type_check_mem of this SqlStats.
        :rtype: int
        """
        return self._type_check_mem

    @type_check_mem.setter
    def type_check_mem(self, type_check_mem):
        """
        Sets the type_check_mem of this SqlStats.
        Typecheck memory


        :param type_check_mem: The type_check_mem of this SqlStats.
        :type: int
        """
        self._type_check_mem = type_check_mem

    @property
    def io_cell_offload_eligible_bytes(self):
        """
        Gets the io_cell_offload_eligible_bytes of this SqlStats.
        Number of I/O bytes which can be filtered by the Exadata storage system


        :return: The io_cell_offload_eligible_bytes of this SqlStats.
        :rtype: int
        """
        return self._io_cell_offload_eligible_bytes

    @io_cell_offload_eligible_bytes.setter
    def io_cell_offload_eligible_bytes(self, io_cell_offload_eligible_bytes):
        """
        Sets the io_cell_offload_eligible_bytes of this SqlStats.
        Number of I/O bytes which can be filtered by the Exadata storage system


        :param io_cell_offload_eligible_bytes: The io_cell_offload_eligible_bytes of this SqlStats.
        :type: int
        """
        self._io_cell_offload_eligible_bytes = io_cell_offload_eligible_bytes

    @property
    def io_interconnect_bytes(self):
        """
        Gets the io_interconnect_bytes of this SqlStats.
        Number of I/O bytes exchanged between Oracle Database and the storage system. Typically used for Cache Fusion or parallel queries


        :return: The io_interconnect_bytes of this SqlStats.
        :rtype: int
        """
        return self._io_interconnect_bytes

    @io_interconnect_bytes.setter
    def io_interconnect_bytes(self, io_interconnect_bytes):
        """
        Sets the io_interconnect_bytes of this SqlStats.
        Number of I/O bytes exchanged between Oracle Database and the storage system. Typically used for Cache Fusion or parallel queries


        :param io_interconnect_bytes: The io_interconnect_bytes of this SqlStats.
        :type: int
        """
        self._io_interconnect_bytes = io_interconnect_bytes

    @property
    def physical_read_requests(self):
        """
        Gets the physical_read_requests of this SqlStats.
        Number of physical read I/O requests issued by the monitored SQL. The requests may not be disk reads


        :return: The physical_read_requests of this SqlStats.
        :rtype: int
        """
        return self._physical_read_requests

    @physical_read_requests.setter
    def physical_read_requests(self, physical_read_requests):
        """
        Sets the physical_read_requests of this SqlStats.
        Number of physical read I/O requests issued by the monitored SQL. The requests may not be disk reads


        :param physical_read_requests: The physical_read_requests of this SqlStats.
        :type: int
        """
        self._physical_read_requests = physical_read_requests

    @property
    def physical_read_bytes(self):
        """
        Gets the physical_read_bytes of this SqlStats.
        Number of bytes read from disks by the monitored SQL


        :return: The physical_read_bytes of this SqlStats.
        :rtype: int
        """
        return self._physical_read_bytes

    @physical_read_bytes.setter
    def physical_read_bytes(self, physical_read_bytes):
        """
        Sets the physical_read_bytes of this SqlStats.
        Number of bytes read from disks by the monitored SQL


        :param physical_read_bytes: The physical_read_bytes of this SqlStats.
        :type: int
        """
        self._physical_read_bytes = physical_read_bytes

    @property
    def physical_write_requests(self):
        """
        Gets the physical_write_requests of this SqlStats.
        Number of physical write I/O requests issued by the monitored SQL


        :return: The physical_write_requests of this SqlStats.
        :rtype: int
        """
        return self._physical_write_requests

    @physical_write_requests.setter
    def physical_write_requests(self, physical_write_requests):
        """
        Sets the physical_write_requests of this SqlStats.
        Number of physical write I/O requests issued by the monitored SQL


        :param physical_write_requests: The physical_write_requests of this SqlStats.
        :type: int
        """
        self._physical_write_requests = physical_write_requests

    @property
    def physical_write_bytes(self):
        """
        Gets the physical_write_bytes of this SqlStats.
        Number of bytes written to disks by the monitored SQL


        :return: The physical_write_bytes of this SqlStats.
        :rtype: int
        """
        return self._physical_write_bytes

    @physical_write_bytes.setter
    def physical_write_bytes(self, physical_write_bytes):
        """
        Sets the physical_write_bytes of this SqlStats.
        Number of bytes written to disks by the monitored SQL


        :param physical_write_bytes: The physical_write_bytes of this SqlStats.
        :type: int
        """
        self._physical_write_bytes = physical_write_bytes

    @property
    def exact_matching_signature(self):
        """
        Gets the exact_matching_signature of this SqlStats.
        exact_matching_signature
        Example: `\"18067345456756876713\"`


        :return: The exact_matching_signature of this SqlStats.
        :rtype: str
        """
        return self._exact_matching_signature

    @exact_matching_signature.setter
    def exact_matching_signature(self, exact_matching_signature):
        """
        Sets the exact_matching_signature of this SqlStats.
        exact_matching_signature
        Example: `\"18067345456756876713\"`


        :param exact_matching_signature: The exact_matching_signature of this SqlStats.
        :type: str
        """
        self._exact_matching_signature = exact_matching_signature

    @property
    def force_matching_signature(self):
        """
        Gets the force_matching_signature of this SqlStats.
        force_matching_signature
        Example: `\"18067345456756876713\"`


        :return: The force_matching_signature of this SqlStats.
        :rtype: str
        """
        return self._force_matching_signature

    @force_matching_signature.setter
    def force_matching_signature(self, force_matching_signature):
        """
        Sets the force_matching_signature of this SqlStats.
        force_matching_signature
        Example: `\"18067345456756876713\"`


        :param force_matching_signature: The force_matching_signature of this SqlStats.
        :type: str
        """
        self._force_matching_signature = force_matching_signature

    @property
    def io_cell_uncompressed_bytes(self):
        """
        Gets the io_cell_uncompressed_bytes of this SqlStats.
        Number of uncompressed bytes (that is, size after decompression) that are offloaded to the Exadata cells


        :return: The io_cell_uncompressed_bytes of this SqlStats.
        :rtype: int
        """
        return self._io_cell_uncompressed_bytes

    @io_cell_uncompressed_bytes.setter
    def io_cell_uncompressed_bytes(self, io_cell_uncompressed_bytes):
        """
        Sets the io_cell_uncompressed_bytes of this SqlStats.
        Number of uncompressed bytes (that is, size after decompression) that are offloaded to the Exadata cells


        :param io_cell_uncompressed_bytes: The io_cell_uncompressed_bytes of this SqlStats.
        :type: int
        """
        self._io_cell_uncompressed_bytes = io_cell_uncompressed_bytes

    @property
    def io_cell_offload_returned_bytes(self):
        """
        Gets the io_cell_offload_returned_bytes of this SqlStats.
        Number of bytes that are returned by Exadata cell through the regular I/O path


        :return: The io_cell_offload_returned_bytes of this SqlStats.
        :rtype: int
        """
        return self._io_cell_offload_returned_bytes

    @io_cell_offload_returned_bytes.setter
    def io_cell_offload_returned_bytes(self, io_cell_offload_returned_bytes):
        """
        Sets the io_cell_offload_returned_bytes of this SqlStats.
        Number of bytes that are returned by Exadata cell through the regular I/O path


        :param io_cell_offload_returned_bytes: The io_cell_offload_returned_bytes of this SqlStats.
        :type: int
        """
        self._io_cell_offload_returned_bytes = io_cell_offload_returned_bytes

    @property
    def child_number(self):
        """
        Gets the child_number of this SqlStats.
        Number of this child cursor


        :return: The child_number of this SqlStats.
        :rtype: int
        """
        return self._child_number

    @child_number.setter
    def child_number(self, child_number):
        """
        Sets the child_number of this SqlStats.
        Number of this child cursor


        :param child_number: The child_number of this SqlStats.
        :type: int
        """
        self._child_number = child_number

    @property
    def command_type(self):
        """
        Gets the command_type of this SqlStats.
        Oracle command type definition


        :return: The command_type of this SqlStats.
        :rtype: int
        """
        return self._command_type

    @command_type.setter
    def command_type(self, command_type):
        """
        Sets the command_type of this SqlStats.
        Oracle command type definition


        :param command_type: The command_type of this SqlStats.
        :type: int
        """
        self._command_type = command_type

    @property
    def users_opening(self):
        """
        Gets the users_opening of this SqlStats.
        Number of users that have any of the child cursors open


        :return: The users_opening of this SqlStats.
        :rtype: int
        """
        return self._users_opening

    @users_opening.setter
    def users_opening(self, users_opening):
        """
        Sets the users_opening of this SqlStats.
        Number of users that have any of the child cursors open


        :param users_opening: The users_opening of this SqlStats.
        :type: int
        """
        self._users_opening = users_opening

    @property
    def users_executing(self):
        """
        Gets the users_executing of this SqlStats.
        Number of users executing the statement


        :return: The users_executing of this SqlStats.
        :rtype: int
        """
        return self._users_executing

    @users_executing.setter
    def users_executing(self, users_executing):
        """
        Sets the users_executing of this SqlStats.
        Number of users executing the statement


        :param users_executing: The users_executing of this SqlStats.
        :type: int
        """
        self._users_executing = users_executing

    @property
    def optimizer_cost(self):
        """
        Gets the optimizer_cost of this SqlStats.
        Cost of this query given by the optimizer


        :return: The optimizer_cost of this SqlStats.
        :rtype: int
        """
        return self._optimizer_cost

    @optimizer_cost.setter
    def optimizer_cost(self, optimizer_cost):
        """
        Sets the optimizer_cost of this SqlStats.
        Cost of this query given by the optimizer


        :param optimizer_cost: The optimizer_cost of this SqlStats.
        :type: int
        """
        self._optimizer_cost = optimizer_cost

    @property
    def full_plan_hash_value(self):
        """
        Gets the full_plan_hash_value of this SqlStats.
        Total Number of rows in SQLStats table


        :return: The full_plan_hash_value of this SqlStats.
        :rtype: str
        """
        return self._full_plan_hash_value

    @full_plan_hash_value.setter
    def full_plan_hash_value(self, full_plan_hash_value):
        """
        Sets the full_plan_hash_value of this SqlStats.
        Total Number of rows in SQLStats table


        :param full_plan_hash_value: The full_plan_hash_value of this SqlStats.
        :type: str
        """
        self._full_plan_hash_value = full_plan_hash_value

    @property
    def module(self):
        """
        Gets the module of this SqlStats.
        Module name


        :return: The module of this SqlStats.
        :rtype: str
        """
        return self._module

    @module.setter
    def module(self, module):
        """
        Sets the module of this SqlStats.
        Module name


        :param module: The module of this SqlStats.
        :type: str
        """
        self._module = module

    @property
    def service(self):
        """
        Gets the service of this SqlStats.
        Service name


        :return: The service of this SqlStats.
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """
        Sets the service of this SqlStats.
        Service name


        :param service: The service of this SqlStats.
        :type: str
        """
        self._service = service

    @property
    def action(self):
        """
        Gets the action of this SqlStats.
        Contains the name of the action that was executing when the SQL statement was first parsed, which is set by calling DBMS_APPLICATION_INFO.SET_ACTION


        :return: The action of this SqlStats.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this SqlStats.
        Contains the name of the action that was executing when the SQL statement was first parsed, which is set by calling DBMS_APPLICATION_INFO.SET_ACTION


        :param action: The action of this SqlStats.
        :type: str
        """
        self._action = action

    @property
    def sql_profile(self):
        """
        Gets the sql_profile of this SqlStats.
        SQL profile used for this statement, if any


        :return: The sql_profile of this SqlStats.
        :rtype: str
        """
        return self._sql_profile

    @sql_profile.setter
    def sql_profile(self, sql_profile):
        """
        Sets the sql_profile of this SqlStats.
        SQL profile used for this statement, if any


        :param sql_profile: The sql_profile of this SqlStats.
        :type: str
        """
        self._sql_profile = sql_profile

    @property
    def sql_patch(self):
        """
        Gets the sql_patch of this SqlStats.
        SQL patch used for this statement, if any


        :return: The sql_patch of this SqlStats.
        :rtype: str
        """
        return self._sql_patch

    @sql_patch.setter
    def sql_patch(self, sql_patch):
        """
        Sets the sql_patch of this SqlStats.
        SQL patch used for this statement, if any


        :param sql_patch: The sql_patch of this SqlStats.
        :type: str
        """
        self._sql_patch = sql_patch

    @property
    def sql_plan_baseline(self):
        """
        Gets the sql_plan_baseline of this SqlStats.
        SQL plan baseline used for this statement, if any


        :return: The sql_plan_baseline of this SqlStats.
        :rtype: str
        """
        return self._sql_plan_baseline

    @sql_plan_baseline.setter
    def sql_plan_baseline(self, sql_plan_baseline):
        """
        Sets the sql_plan_baseline of this SqlStats.
        SQL plan baseline used for this statement, if any


        :param sql_plan_baseline: The sql_plan_baseline of this SqlStats.
        :type: str
        """
        self._sql_plan_baseline = sql_plan_baseline

    @property
    def delta_execution_count(self):
        """
        Gets the delta_execution_count of this SqlStats.
        Number of executions for the cursor since the last AWR snapshot


        :return: The delta_execution_count of this SqlStats.
        :rtype: int
        """
        return self._delta_execution_count

    @delta_execution_count.setter
    def delta_execution_count(self, delta_execution_count):
        """
        Sets the delta_execution_count of this SqlStats.
        Number of executions for the cursor since the last AWR snapshot


        :param delta_execution_count: The delta_execution_count of this SqlStats.
        :type: int
        """
        self._delta_execution_count = delta_execution_count

    @property
    def delta_cpu_time(self):
        """
        Gets the delta_cpu_time of this SqlStats.
        CPU time (in microseconds) for the cursor since the last AWR snapshot


        :return: The delta_cpu_time of this SqlStats.
        :rtype: int
        """
        return self._delta_cpu_time

    @delta_cpu_time.setter
    def delta_cpu_time(self, delta_cpu_time):
        """
        Sets the delta_cpu_time of this SqlStats.
        CPU time (in microseconds) for the cursor since the last AWR snapshot


        :param delta_cpu_time: The delta_cpu_time of this SqlStats.
        :type: int
        """
        self._delta_cpu_time = delta_cpu_time

    @property
    def delta_io_bytes(self):
        """
        Gets the delta_io_bytes of this SqlStats.
        Number of I/O bytes exchanged between the Oracle database and the storage system for the cursor since the last AWR snapshot


        :return: The delta_io_bytes of this SqlStats.
        :rtype: int
        """
        return self._delta_io_bytes

    @delta_io_bytes.setter
    def delta_io_bytes(self, delta_io_bytes):
        """
        Sets the delta_io_bytes of this SqlStats.
        Number of I/O bytes exchanged between the Oracle database and the storage system for the cursor since the last AWR snapshot


        :param delta_io_bytes: The delta_io_bytes of this SqlStats.
        :type: int
        """
        self._delta_io_bytes = delta_io_bytes

    @property
    def delta_cpu_rank(self):
        """
        Gets the delta_cpu_rank of this SqlStats.
        Rank based on CPU Consumption


        :return: The delta_cpu_rank of this SqlStats.
        :rtype: int
        """
        return self._delta_cpu_rank

    @delta_cpu_rank.setter
    def delta_cpu_rank(self, delta_cpu_rank):
        """
        Sets the delta_cpu_rank of this SqlStats.
        Rank based on CPU Consumption


        :param delta_cpu_rank: The delta_cpu_rank of this SqlStats.
        :type: int
        """
        self._delta_cpu_rank = delta_cpu_rank

    @property
    def delta_execs_rank(self):
        """
        Gets the delta_execs_rank of this SqlStats.
        Rank based on number of execution


        :return: The delta_execs_rank of this SqlStats.
        :rtype: int
        """
        return self._delta_execs_rank

    @delta_execs_rank.setter
    def delta_execs_rank(self, delta_execs_rank):
        """
        Sets the delta_execs_rank of this SqlStats.
        Rank based on number of execution


        :param delta_execs_rank: The delta_execs_rank of this SqlStats.
        :type: int
        """
        self._delta_execs_rank = delta_execs_rank

    @property
    def sharable_mem_rank(self):
        """
        Gets the sharable_mem_rank of this SqlStats.
        Rank based on sharable memory


        :return: The sharable_mem_rank of this SqlStats.
        :rtype: int
        """
        return self._sharable_mem_rank

    @sharable_mem_rank.setter
    def sharable_mem_rank(self, sharable_mem_rank):
        """
        Sets the sharable_mem_rank of this SqlStats.
        Rank based on sharable memory


        :param sharable_mem_rank: The sharable_mem_rank of this SqlStats.
        :type: int
        """
        self._sharable_mem_rank = sharable_mem_rank

    @property
    def delta_io_rank(self):
        """
        Gets the delta_io_rank of this SqlStats.
        Rank based on I/O Consumption


        :return: The delta_io_rank of this SqlStats.
        :rtype: int
        """
        return self._delta_io_rank

    @delta_io_rank.setter
    def delta_io_rank(self, delta_io_rank):
        """
        Sets the delta_io_rank of this SqlStats.
        Rank based on I/O Consumption


        :param delta_io_rank: The delta_io_rank of this SqlStats.
        :type: int
        """
        self._delta_io_rank = delta_io_rank

    @property
    def harmonic_sum(self):
        """
        Gets the harmonic_sum of this SqlStats.
        Harmonic sum based on ranking parameters


        :return: The harmonic_sum of this SqlStats.
        :rtype: int
        """
        return self._harmonic_sum

    @harmonic_sum.setter
    def harmonic_sum(self, harmonic_sum):
        """
        Sets the harmonic_sum of this SqlStats.
        Harmonic sum based on ranking parameters


        :param harmonic_sum: The harmonic_sum of this SqlStats.
        :type: int
        """
        self._harmonic_sum = harmonic_sum

    @property
    def wt_harmonic_sum(self):
        """
        Gets the wt_harmonic_sum of this SqlStats.
        Weight based harmonic sum of ranking parameters


        :return: The wt_harmonic_sum of this SqlStats.
        :rtype: int
        """
        return self._wt_harmonic_sum

    @wt_harmonic_sum.setter
    def wt_harmonic_sum(self, wt_harmonic_sum):
        """
        Sets the wt_harmonic_sum of this SqlStats.
        Weight based harmonic sum of ranking parameters


        :param wt_harmonic_sum: The wt_harmonic_sum of this SqlStats.
        :type: int
        """
        self._wt_harmonic_sum = wt_harmonic_sum

    @property
    def total_sql_count(self):
        """
        Gets the total_sql_count of this SqlStats.
        Total number of rows in SQLStats table


        :return: The total_sql_count of this SqlStats.
        :rtype: int
        """
        return self._total_sql_count

    @total_sql_count.setter
    def total_sql_count(self, total_sql_count):
        """
        Sets the total_sql_count of this SqlStats.
        Total number of rows in SQLStats table


        :param total_sql_count: The total_sql_count of this SqlStats.
        :type: int
        """
        self._total_sql_count = total_sql_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class KeyPhrase(object):
    """
    Key phrase for the given text.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new KeyPhrase object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param text:
            The value to assign to the text property of this KeyPhrase.
        :type text: str

        :param score:
            The value to assign to the score property of this KeyPhrase.
        :type score: float

        """
        self.swagger_types = {
            'text': 'str',
            'score': 'float'
        }

        self.attribute_map = {
            'text': 'text',
            'score': 'score'
        }

        self._text = None
        self._score = None

    @property
    def text(self):
        """
        **[Required]** Gets the text of this KeyPhrase.
        Key phrase exreacted from given text.


        :return: The text of this KeyPhrase.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this KeyPhrase.
        Key phrase exreacted from given text.


        :param text: The text of this KeyPhrase.
        :type: str
        """
        self._text = text

    @property
    def score(self):
        """
        **[Required]** Gets the score of this KeyPhrase.
        Score or confidence of the key phrase.
        Example: `0.9999856066867399`


        :return: The score of this KeyPhrase.
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """
        Sets the score of this KeyPhrase.
        Score or confidence of the key phrase.
        Example: `0.9999856066867399`


        :param score: The score of this KeyPhrase.
        :type: float
        """
        self._score = score

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AwrSourceSummary(object):
    """
    Summary of an AwrSource.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AwrSourceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param awr_hub_id:
            The value to assign to the awr_hub_id property of this AwrSourceSummary.
        :type awr_hub_id: str

        :param name:
            The value to assign to the name property of this AwrSourceSummary.
        :type name: str

        :param awr_source_database_id:
            The value to assign to the awr_source_database_id property of this AwrSourceSummary.
        :type awr_source_database_id: str

        :param snapshots_uploaded:
            The value to assign to the snapshots_uploaded property of this AwrSourceSummary.
        :type snapshots_uploaded: float

        :param min_snapshot_identifier:
            The value to assign to the min_snapshot_identifier property of this AwrSourceSummary.
        :type min_snapshot_identifier: float

        :param max_snapshot_identifier:
            The value to assign to the max_snapshot_identifier property of this AwrSourceSummary.
        :type max_snapshot_identifier: float

        :param time_first_snapshot_generated:
            The value to assign to the time_first_snapshot_generated property of this AwrSourceSummary.
        :type time_first_snapshot_generated: datetime

        :param time_last_snapshot_generated:
            The value to assign to the time_last_snapshot_generated property of this AwrSourceSummary.
        :type time_last_snapshot_generated: datetime

        :param hours_since_last_import:
            The value to assign to the hours_since_last_import property of this AwrSourceSummary.
        :type hours_since_last_import: float

        """
        self.swagger_types = {
            'awr_hub_id': 'str',
            'name': 'str',
            'awr_source_database_id': 'str',
            'snapshots_uploaded': 'float',
            'min_snapshot_identifier': 'float',
            'max_snapshot_identifier': 'float',
            'time_first_snapshot_generated': 'datetime',
            'time_last_snapshot_generated': 'datetime',
            'hours_since_last_import': 'float'
        }

        self.attribute_map = {
            'awr_hub_id': 'awrHubId',
            'name': 'name',
            'awr_source_database_id': 'awrSourceDatabaseId',
            'snapshots_uploaded': 'snapshotsUploaded',
            'min_snapshot_identifier': 'minSnapshotIdentifier',
            'max_snapshot_identifier': 'maxSnapshotIdentifier',
            'time_first_snapshot_generated': 'timeFirstSnapshotGenerated',
            'time_last_snapshot_generated': 'timeLastSnapshotGenerated',
            'hours_since_last_import': 'hoursSinceLastImport'
        }

        self._awr_hub_id = None
        self._name = None
        self._awr_source_database_id = None
        self._snapshots_uploaded = None
        self._min_snapshot_identifier = None
        self._max_snapshot_identifier = None
        self._time_first_snapshot_generated = None
        self._time_last_snapshot_generated = None
        self._hours_since_last_import = None

    @property
    def awr_hub_id(self):
        """
        **[Required]** Gets the awr_hub_id of this AwrSourceSummary.
        AWR Hub OCID


        :return: The awr_hub_id of this AwrSourceSummary.
        :rtype: str
        """
        return self._awr_hub_id

    @awr_hub_id.setter
    def awr_hub_id(self, awr_hub_id):
        """
        Sets the awr_hub_id of this AwrSourceSummary.
        AWR Hub OCID


        :param awr_hub_id: The awr_hub_id of this AwrSourceSummary.
        :type: str
        """
        self._awr_hub_id = awr_hub_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this AwrSourceSummary.
        Database name of the Source database for which AWR Data will be uploaded to AWR Hub.


        :return: The name of this AwrSourceSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this AwrSourceSummary.
        Database name of the Source database for which AWR Data will be uploaded to AWR Hub.


        :param name: The name of this AwrSourceSummary.
        :type: str
        """
        self._name = name

    @property
    def awr_source_database_id(self):
        """
        **[Required]** Gets the awr_source_database_id of this AwrSourceSummary.
        DatabaseId of the Source database for which AWR Data will be uploaded to AWR Hub.


        :return: The awr_source_database_id of this AwrSourceSummary.
        :rtype: str
        """
        return self._awr_source_database_id

    @awr_source_database_id.setter
    def awr_source_database_id(self, awr_source_database_id):
        """
        Sets the awr_source_database_id of this AwrSourceSummary.
        DatabaseId of the Source database for which AWR Data will be uploaded to AWR Hub.


        :param awr_source_database_id: The awr_source_database_id of this AwrSourceSummary.
        :type: str
        """
        self._awr_source_database_id = awr_source_database_id

    @property
    def snapshots_uploaded(self):
        """
        **[Required]** Gets the snapshots_uploaded of this AwrSourceSummary.
        Number of AWR snapshots uploaded from the Source database.


        :return: The snapshots_uploaded of this AwrSourceSummary.
        :rtype: float
        """
        return self._snapshots_uploaded

    @snapshots_uploaded.setter
    def snapshots_uploaded(self, snapshots_uploaded):
        """
        Sets the snapshots_uploaded of this AwrSourceSummary.
        Number of AWR snapshots uploaded from the Source database.


        :param snapshots_uploaded: The snapshots_uploaded of this AwrSourceSummary.
        :type: float
        """
        self._snapshots_uploaded = snapshots_uploaded

    @property
    def min_snapshot_identifier(self):
        """
        **[Required]** Gets the min_snapshot_identifier of this AwrSourceSummary.
        The minimum snapshot identifier of the source database for which AWR data is uploaded to AWR Hub.


        :return: The min_snapshot_identifier of this AwrSourceSummary.
        :rtype: float
        """
        return self._min_snapshot_identifier

    @min_snapshot_identifier.setter
    def min_snapshot_identifier(self, min_snapshot_identifier):
        """
        Sets the min_snapshot_identifier of this AwrSourceSummary.
        The minimum snapshot identifier of the source database for which AWR data is uploaded to AWR Hub.


        :param min_snapshot_identifier: The min_snapshot_identifier of this AwrSourceSummary.
        :type: float
        """
        self._min_snapshot_identifier = min_snapshot_identifier

    @property
    def max_snapshot_identifier(self):
        """
        **[Required]** Gets the max_snapshot_identifier of this AwrSourceSummary.
        The maximum snapshot identifier of the source database for which AWR data is uploaded to AWR Hub.


        :return: The max_snapshot_identifier of this AwrSourceSummary.
        :rtype: float
        """
        return self._max_snapshot_identifier

    @max_snapshot_identifier.setter
    def max_snapshot_identifier(self, max_snapshot_identifier):
        """
        Sets the max_snapshot_identifier of this AwrSourceSummary.
        The maximum snapshot identifier of the source database for which AWR data is uploaded to AWR Hub.


        :param max_snapshot_identifier: The max_snapshot_identifier of this AwrSourceSummary.
        :type: float
        """
        self._max_snapshot_identifier = max_snapshot_identifier

    @property
    def time_first_snapshot_generated(self):
        """
        **[Required]** Gets the time_first_snapshot_generated of this AwrSourceSummary.
        The time at which the earliest snapshot was generated in the source database for which data is uploaded to AWR Hub. An RFC3339 formatted datetime string


        :return: The time_first_snapshot_generated of this AwrSourceSummary.
        :rtype: datetime
        """
        return self._time_first_snapshot_generated

    @time_first_snapshot_generated.setter
    def time_first_snapshot_generated(self, time_first_snapshot_generated):
        """
        Sets the time_first_snapshot_generated of this AwrSourceSummary.
        The time at which the earliest snapshot was generated in the source database for which data is uploaded to AWR Hub. An RFC3339 formatted datetime string


        :param time_first_snapshot_generated: The time_first_snapshot_generated of this AwrSourceSummary.
        :type: datetime
        """
        self._time_first_snapshot_generated = time_first_snapshot_generated

    @property
    def time_last_snapshot_generated(self):
        """
        **[Required]** Gets the time_last_snapshot_generated of this AwrSourceSummary.
        The time at which the latest snapshot was generated in the source database for which data is uploaded to AWR Hub. An RFC3339 formatted datetime string


        :return: The time_last_snapshot_generated of this AwrSourceSummary.
        :rtype: datetime
        """
        return self._time_last_snapshot_generated

    @time_last_snapshot_generated.setter
    def time_last_snapshot_generated(self, time_last_snapshot_generated):
        """
        Sets the time_last_snapshot_generated of this AwrSourceSummary.
        The time at which the latest snapshot was generated in the source database for which data is uploaded to AWR Hub. An RFC3339 formatted datetime string


        :param time_last_snapshot_generated: The time_last_snapshot_generated of this AwrSourceSummary.
        :type: datetime
        """
        self._time_last_snapshot_generated = time_last_snapshot_generated

    @property
    def hours_since_last_import(self):
        """
        **[Required]** Gets the hours_since_last_import of this AwrSourceSummary.
        Number of hours since last AWR snapshots import happened from the Source database.


        :return: The hours_since_last_import of this AwrSourceSummary.
        :rtype: float
        """
        return self._hours_since_last_import

    @hours_since_last_import.setter
    def hours_since_last_import(self, hours_since_last_import):
        """
        Sets the hours_since_last_import of this AwrSourceSummary.
        Number of hours since last AWR snapshots import happened from the Source database.


        :param hours_since_last_import: The hours_since_last_import of this AwrSourceSummary.
        :type: float
        """
        self._hours_since_last_import = hours_since_last_import

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UserSummary(object):
    """
    The summary of a specific User.
    """

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "OPEN"
    STATUS_OPEN = "OPEN"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED"
    STATUS_EXPIRED = "EXPIRED"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED_GRACE"
    STATUS_EXPIRED_GRACE = "EXPIRED_GRACE"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "LOCKED"
    STATUS_LOCKED = "LOCKED"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "LOCKED_TIMED"
    STATUS_LOCKED_TIMED = "LOCKED_TIMED"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED_AND_LOCKED"
    STATUS_EXPIRED_AND_LOCKED = "EXPIRED_AND_LOCKED"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED_GRACE_AND_LOCKED"
    STATUS_EXPIRED_GRACE_AND_LOCKED = "EXPIRED_GRACE_AND_LOCKED"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED_AND_LOCKED_TIMED"
    STATUS_EXPIRED_AND_LOCKED_TIMED = "EXPIRED_AND_LOCKED_TIMED"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED_GRACE_AND_LOCKED_TIMED"
    STATUS_EXPIRED_GRACE_AND_LOCKED_TIMED = "EXPIRED_GRACE_AND_LOCKED_TIMED"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "OPEN_AND_IN_ROLLOVER"
    STATUS_OPEN_AND_IN_ROLLOVER = "OPEN_AND_IN_ROLLOVER"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED_AND_IN_ROLLOVER"
    STATUS_EXPIRED_AND_IN_ROLLOVER = "EXPIRED_AND_IN_ROLLOVER"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "LOCKED_AND_IN_ROLLOVER"
    STATUS_LOCKED_AND_IN_ROLLOVER = "LOCKED_AND_IN_ROLLOVER"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED_AND_LOCKED_AND_IN_ROLLOVER"
    STATUS_EXPIRED_AND_LOCKED_AND_IN_ROLLOVER = "EXPIRED_AND_LOCKED_AND_IN_ROLLOVER"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "LOCKED_TIMED_AND_IN_ROLLOVER"
    STATUS_LOCKED_TIMED_AND_IN_ROLLOVER = "LOCKED_TIMED_AND_IN_ROLLOVER"

    #: A constant which can be used with the status property of a UserSummary.
    #: This constant has a value of "EXPIRED_AND_LOCKED_TIMED_AND_IN_ROL"
    STATUS_EXPIRED_AND_LOCKED_TIMED_AND_IN_ROL = "EXPIRED_AND_LOCKED_TIMED_AND_IN_ROL"

    def __init__(self, **kwargs):
        """
        Initializes a new UserSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this UserSummary.
        :type name: str

        :param status:
            The value to assign to the status property of this UserSummary.
            Allowed values for this property are: "OPEN", "EXPIRED", "EXPIRED_GRACE", "LOCKED", "LOCKED_TIMED", "EXPIRED_AND_LOCKED", "EXPIRED_GRACE_AND_LOCKED", "EXPIRED_AND_LOCKED_TIMED", "EXPIRED_GRACE_AND_LOCKED_TIMED", "OPEN_AND_IN_ROLLOVER", "EXPIRED_AND_IN_ROLLOVER", "LOCKED_AND_IN_ROLLOVER", "EXPIRED_AND_LOCKED_AND_IN_ROLLOVER", "LOCKED_TIMED_AND_IN_ROLLOVER", "EXPIRED_AND_LOCKED_TIMED_AND_IN_ROL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param time_expiring:
            The value to assign to the time_expiring property of this UserSummary.
        :type time_expiring: datetime

        :param default_tablespace:
            The value to assign to the default_tablespace property of this UserSummary.
        :type default_tablespace: str

        :param temp_tablespace:
            The value to assign to the temp_tablespace property of this UserSummary.
        :type temp_tablespace: str

        :param time_created:
            The value to assign to the time_created property of this UserSummary.
        :type time_created: datetime

        :param profile:
            The value to assign to the profile property of this UserSummary.
        :type profile: str

        """
        self.swagger_types = {
            'name': 'str',
            'status': 'str',
            'time_expiring': 'datetime',
            'default_tablespace': 'str',
            'temp_tablespace': 'str',
            'time_created': 'datetime',
            'profile': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'status': 'status',
            'time_expiring': 'timeExpiring',
            'default_tablespace': 'defaultTablespace',
            'temp_tablespace': 'tempTablespace',
            'time_created': 'timeCreated',
            'profile': 'profile'
        }

        self._name = None
        self._status = None
        self._time_expiring = None
        self._default_tablespace = None
        self._temp_tablespace = None
        self._time_created = None
        self._profile = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this UserSummary.
        The name of the User.


        :return: The name of this UserSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UserSummary.
        The name of the User.


        :param name: The name of this UserSummary.
        :type: str
        """
        self._name = name

    @property
    def status(self):
        """
        **[Required]** Gets the status of this UserSummary.
        The account status of the User

        Allowed values for this property are: "OPEN", "EXPIRED", "EXPIRED_GRACE", "LOCKED", "LOCKED_TIMED", "EXPIRED_AND_LOCKED", "EXPIRED_GRACE_AND_LOCKED", "EXPIRED_AND_LOCKED_TIMED", "EXPIRED_GRACE_AND_LOCKED_TIMED", "OPEN_AND_IN_ROLLOVER", "EXPIRED_AND_IN_ROLLOVER", "LOCKED_AND_IN_ROLLOVER", "EXPIRED_AND_LOCKED_AND_IN_ROLLOVER", "LOCKED_TIMED_AND_IN_ROLLOVER", "EXPIRED_AND_LOCKED_TIMED_AND_IN_ROL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this UserSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this UserSummary.
        The account status of the User


        :param status: The status of this UserSummary.
        :type: str
        """
        allowed_values = ["OPEN", "EXPIRED", "EXPIRED_GRACE", "LOCKED", "LOCKED_TIMED", "EXPIRED_AND_LOCKED", "EXPIRED_GRACE_AND_LOCKED", "EXPIRED_AND_LOCKED_TIMED", "EXPIRED_GRACE_AND_LOCKED_TIMED", "OPEN_AND_IN_ROLLOVER", "EXPIRED_AND_IN_ROLLOVER", "LOCKED_AND_IN_ROLLOVER", "EXPIRED_AND_LOCKED_AND_IN_ROLLOVER", "LOCKED_TIMED_AND_IN_ROLLOVER", "EXPIRED_AND_LOCKED_TIMED_AND_IN_ROL"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def time_expiring(self):
        """
        Gets the time_expiring of this UserSummary.
        The date of expiration of the account


        :return: The time_expiring of this UserSummary.
        :rtype: datetime
        """
        return self._time_expiring

    @time_expiring.setter
    def time_expiring(self, time_expiring):
        """
        Sets the time_expiring of this UserSummary.
        The date of expiration of the account


        :param time_expiring: The time_expiring of this UserSummary.
        :type: datetime
        """
        self._time_expiring = time_expiring

    @property
    def default_tablespace(self):
        """
        **[Required]** Gets the default_tablespace of this UserSummary.
        The default tablespace for data.


        :return: The default_tablespace of this UserSummary.
        :rtype: str
        """
        return self._default_tablespace

    @default_tablespace.setter
    def default_tablespace(self, default_tablespace):
        """
        Sets the default_tablespace of this UserSummary.
        The default tablespace for data.


        :param default_tablespace: The default_tablespace of this UserSummary.
        :type: str
        """
        self._default_tablespace = default_tablespace

    @property
    def temp_tablespace(self):
        """
        **[Required]** Gets the temp_tablespace of this UserSummary.
        The name of the default tablespace for temporary tables or the name of a tablespace group.


        :return: The temp_tablespace of this UserSummary.
        :rtype: str
        """
        return self._temp_tablespace

    @temp_tablespace.setter
    def temp_tablespace(self, temp_tablespace):
        """
        Sets the temp_tablespace of this UserSummary.
        The name of the default tablespace for temporary tables or the name of a tablespace group.


        :param temp_tablespace: The temp_tablespace of this UserSummary.
        :type: str
        """
        self._temp_tablespace = temp_tablespace

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this UserSummary.
        The User creation date.


        :return: The time_created of this UserSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this UserSummary.
        The User creation date.


        :param time_created: The time_created of this UserSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def profile(self):
        """
        **[Required]** Gets the profile of this UserSummary.
        The User resource profile name.


        :return: The profile of this UserSummary.
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """
        Sets the profile of this UserSummary.
        The User resource profile name.


        :param profile: The profile of this UserSummary.
        :type: str
        """
        self._profile = profile

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExadataMemberCollection(object):
    """
    Partial definition of the exadata insight resource.
    """

    #: A constant which can be used with the exadata_type property of a ExadataMemberCollection.
    #: This constant has a value of "DBMACHINE"
    EXADATA_TYPE_DBMACHINE = "DBMACHINE"

    #: A constant which can be used with the exadata_type property of a ExadataMemberCollection.
    #: This constant has a value of "EXACS"
    EXADATA_TYPE_EXACS = "EXACS"

    #: A constant which can be used with the exadata_type property of a ExadataMemberCollection.
    #: This constant has a value of "EXACC"
    EXADATA_TYPE_EXACC = "EXACC"

    #: A constant which can be used with the exadata_rack_type property of a ExadataMemberCollection.
    #: This constant has a value of "FULL"
    EXADATA_RACK_TYPE_FULL = "FULL"

    #: A constant which can be used with the exadata_rack_type property of a ExadataMemberCollection.
    #: This constant has a value of "HALF"
    EXADATA_RACK_TYPE_HALF = "HALF"

    #: A constant which can be used with the exadata_rack_type property of a ExadataMemberCollection.
    #: This constant has a value of "QUARTER"
    EXADATA_RACK_TYPE_QUARTER = "QUARTER"

    #: A constant which can be used with the exadata_rack_type property of a ExadataMemberCollection.
    #: This constant has a value of "EIGHTH"
    EXADATA_RACK_TYPE_EIGHTH = "EIGHTH"

    def __init__(self, **kwargs):
        """
        Initializes a new ExadataMemberCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param exadata_insight_id:
            The value to assign to the exadata_insight_id property of this ExadataMemberCollection.
        :type exadata_insight_id: str

        :param exadata_name:
            The value to assign to the exadata_name property of this ExadataMemberCollection.
        :type exadata_name: str

        :param exadata_display_name:
            The value to assign to the exadata_display_name property of this ExadataMemberCollection.
        :type exadata_display_name: str

        :param exadata_type:
            The value to assign to the exadata_type property of this ExadataMemberCollection.
            Allowed values for this property are: "DBMACHINE", "EXACS", "EXACC", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type exadata_type: str

        :param exadata_rack_type:
            The value to assign to the exadata_rack_type property of this ExadataMemberCollection.
            Allowed values for this property are: "FULL", "HALF", "QUARTER", "EIGHTH", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type exadata_rack_type: str

        :param items:
            The value to assign to the items property of this ExadataMemberCollection.
        :type items: list[oci.opsi.models.ExadataMemberSummary]

        """
        self.swagger_types = {
            'exadata_insight_id': 'str',
            'exadata_name': 'str',
            'exadata_display_name': 'str',
            'exadata_type': 'str',
            'exadata_rack_type': 'str',
            'items': 'list[ExadataMemberSummary]'
        }

        self.attribute_map = {
            'exadata_insight_id': 'exadataInsightId',
            'exadata_name': 'exadataName',
            'exadata_display_name': 'exadataDisplayName',
            'exadata_type': 'exadataType',
            'exadata_rack_type': 'exadataRackType',
            'items': 'items'
        }

        self._exadata_insight_id = None
        self._exadata_name = None
        self._exadata_display_name = None
        self._exadata_type = None
        self._exadata_rack_type = None
        self._items = None

    @property
    def exadata_insight_id(self):
        """
        **[Required]** Gets the exadata_insight_id of this ExadataMemberCollection.
        The `OCID`__ of the Exadata insight.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The exadata_insight_id of this ExadataMemberCollection.
        :rtype: str
        """
        return self._exadata_insight_id

    @exadata_insight_id.setter
    def exadata_insight_id(self, exadata_insight_id):
        """
        Sets the exadata_insight_id of this ExadataMemberCollection.
        The `OCID`__ of the Exadata insight.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param exadata_insight_id: The exadata_insight_id of this ExadataMemberCollection.
        :type: str
        """
        self._exadata_insight_id = exadata_insight_id

    @property
    def exadata_name(self):
        """
        **[Required]** Gets the exadata_name of this ExadataMemberCollection.
        The Exadata system name. If the Exadata systems managed by Enterprise Manager, the name is unique amongst the Exadata systems managed by the same Enterprise Manager.


        :return: The exadata_name of this ExadataMemberCollection.
        :rtype: str
        """
        return self._exadata_name

    @exadata_name.setter
    def exadata_name(self, exadata_name):
        """
        Sets the exadata_name of this ExadataMemberCollection.
        The Exadata system name. If the Exadata systems managed by Enterprise Manager, the name is unique amongst the Exadata systems managed by the same Enterprise Manager.


        :param exadata_name: The exadata_name of this ExadataMemberCollection.
        :type: str
        """
        self._exadata_name = exadata_name

    @property
    def exadata_display_name(self):
        """
        **[Required]** Gets the exadata_display_name of this ExadataMemberCollection.
        The user-friendly name for the Exadata system. The name does not have to be unique.


        :return: The exadata_display_name of this ExadataMemberCollection.
        :rtype: str
        """
        return self._exadata_display_name

    @exadata_display_name.setter
    def exadata_display_name(self, exadata_display_name):
        """
        Sets the exadata_display_name of this ExadataMemberCollection.
        The user-friendly name for the Exadata system. The name does not have to be unique.


        :param exadata_display_name: The exadata_display_name of this ExadataMemberCollection.
        :type: str
        """
        self._exadata_display_name = exadata_display_name

    @property
    def exadata_type(self):
        """
        **[Required]** Gets the exadata_type of this ExadataMemberCollection.
        Operations Insights internal representation of the the Exadata system type.

        Allowed values for this property are: "DBMACHINE", "EXACS", "EXACC", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The exadata_type of this ExadataMemberCollection.
        :rtype: str
        """
        return self._exadata_type

    @exadata_type.setter
    def exadata_type(self, exadata_type):
        """
        Sets the exadata_type of this ExadataMemberCollection.
        Operations Insights internal representation of the the Exadata system type.


        :param exadata_type: The exadata_type of this ExadataMemberCollection.
        :type: str
        """
        allowed_values = ["DBMACHINE", "EXACS", "EXACC"]
        if not value_allowed_none_or_none_sentinel(exadata_type, allowed_values):
            exadata_type = 'UNKNOWN_ENUM_VALUE'
        self._exadata_type = exadata_type

    @property
    def exadata_rack_type(self):
        """
        **[Required]** Gets the exadata_rack_type of this ExadataMemberCollection.
        Exadata rack type.

        Allowed values for this property are: "FULL", "HALF", "QUARTER", "EIGHTH", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The exadata_rack_type of this ExadataMemberCollection.
        :rtype: str
        """
        return self._exadata_rack_type

    @exadata_rack_type.setter
    def exadata_rack_type(self, exadata_rack_type):
        """
        Sets the exadata_rack_type of this ExadataMemberCollection.
        Exadata rack type.


        :param exadata_rack_type: The exadata_rack_type of this ExadataMemberCollection.
        :type: str
        """
        allowed_values = ["FULL", "HALF", "QUARTER", "EIGHTH"]
        if not value_allowed_none_or_none_sentinel(exadata_rack_type, allowed_values):
            exadata_rack_type = 'UNKNOWN_ENUM_VALUE'
        self._exadata_rack_type = exadata_rack_type

    @property
    def items(self):
        """
        **[Required]** Gets the items of this ExadataMemberCollection.
        Collection of Exadata members


        :return: The items of this ExadataMemberCollection.
        :rtype: list[oci.opsi.models.ExadataMemberSummary]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this ExadataMemberCollection.
        Collection of Exadata members


        :param items: The items of this ExadataMemberCollection.
        :type: list[oci.opsi.models.ExadataMemberSummary]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EvaluatedMetric(object):
    """
    One of the metrics that will be evaluated by profiles using this profile level.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EvaluatedMetric object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this EvaluatedMetric.
        :type name: str

        :param statistic:
            The value to assign to the statistic property of this EvaluatedMetric.
        :type statistic: str

        :param threshold:
            The value to assign to the threshold property of this EvaluatedMetric.
        :type threshold: float

        :param target:
            The value to assign to the target property of this EvaluatedMetric.
        :type target: float

        """
        self.swagger_types = {
            'name': 'str',
            'statistic': 'str',
            'threshold': 'float',
            'target': 'float'
        }

        self.attribute_map = {
            'name': 'name',
            'statistic': 'statistic',
            'threshold': 'threshold',
            'target': 'target'
        }

        self._name = None
        self._statistic = None
        self._threshold = None
        self._target = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this EvaluatedMetric.
        The name of the metric (e.g., `CpuUtilization`).


        :return: The name of this EvaluatedMetric.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EvaluatedMetric.
        The name of the metric (e.g., `CpuUtilization`).


        :param name: The name of this EvaluatedMetric.
        :type: str
        """
        self._name = name

    @property
    def statistic(self):
        """
        **[Required]** Gets the statistic of this EvaluatedMetric.
        The name of the statistic (e.g., `p95`).


        :return: The statistic of this EvaluatedMetric.
        :rtype: str
        """
        return self._statistic

    @statistic.setter
    def statistic(self, statistic):
        """
        Sets the statistic of this EvaluatedMetric.
        The name of the statistic (e.g., `p95`).


        :param statistic: The statistic of this EvaluatedMetric.
        :type: str
        """
        self._statistic = statistic

    @property
    def threshold(self):
        """
        **[Required]** Gets the threshold of this EvaluatedMetric.
        The threshold that must be crossed for the recommendation to appear.


        :return: The threshold of this EvaluatedMetric.
        :rtype: float
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """
        Sets the threshold of this EvaluatedMetric.
        The threshold that must be crossed for the recommendation to appear.


        :param threshold: The threshold of this EvaluatedMetric.
        :type: float
        """
        self._threshold = threshold

    @property
    def target(self):
        """
        Gets the target of this EvaluatedMetric.
        Optional. The metric value that the recommendation will target.


        :return: The target of this EvaluatedMetric.
        :rtype: float
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this EvaluatedMetric.
        Optional. The metric value that the recommendation will target.


        :param target: The target of this EvaluatedMetric.
        :type: float
        """
        self._target = target

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Catalog(object):
    """
    A data catalog enables you to collect, organize, find, access, understand, enrich, and activate technical, business, and operational metadata.
    """

    #: A constant which can be used with the lifecycle_state property of a Catalog.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Catalog.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Catalog.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Catalog.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Catalog.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Catalog.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Catalog.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Catalog.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    def __init__(self, **kwargs):
        """
        Initializes a new Catalog object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Catalog.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this Catalog.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Catalog.
        :type compartment_id: str

        :param time_created:
            The value to assign to the time_created property of this Catalog.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this Catalog.
        :type time_updated: datetime

        :param service_api_url:
            The value to assign to the service_api_url property of this Catalog.
        :type service_api_url: str

        :param service_console_url:
            The value to assign to the service_console_url property of this Catalog.
        :type service_console_url: str

        :param number_of_objects:
            The value to assign to the number_of_objects property of this Catalog.
        :type number_of_objects: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Catalog.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this Catalog.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Catalog.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Catalog.
        :type defined_tags: dict(str, dict(str, object))

        :param attached_catalog_private_endpoints:
            The value to assign to the attached_catalog_private_endpoints property of this Catalog.
        :type attached_catalog_private_endpoints: list[str]

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'service_api_url': 'str',
            'service_console_url': 'str',
            'number_of_objects': 'int',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'attached_catalog_private_endpoints': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'service_api_url': 'serviceApiUrl',
            'service_console_url': 'serviceConsoleUrl',
            'number_of_objects': 'numberOfObjects',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'attached_catalog_private_endpoints': 'attachedCatalogPrivateEndpoints'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._time_created = None
        self._time_updated = None
        self._service_api_url = None
        self._service_console_url = None
        self._number_of_objects = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._attached_catalog_private_endpoints = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Catalog.
        OCID of the data catalog instance.


        :return: The id of this Catalog.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Catalog.
        OCID of the data catalog instance.


        :param id: The id of this Catalog.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this Catalog.
        Data catalog identifier, which can be renamed.


        :return: The display_name of this Catalog.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Catalog.
        Data catalog identifier, which can be renamed.


        :param display_name: The display_name of this Catalog.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Catalog.
        Compartment identifier.


        :return: The compartment_id of this Catalog.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Catalog.
        Compartment identifier.


        :param compartment_id: The compartment_id of this Catalog.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def time_created(self):
        """
        Gets the time_created of this Catalog.
        The time the data catalog was created. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this Catalog.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Catalog.
        The time the data catalog was created. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this Catalog.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this Catalog.
        The time the data catalog was updated. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this Catalog.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this Catalog.
        The time the data catalog was updated. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this Catalog.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def service_api_url(self):
        """
        Gets the service_api_url of this Catalog.
        The REST front endpoint URL to the data catalog instance.


        :return: The service_api_url of this Catalog.
        :rtype: str
        """
        return self._service_api_url

    @service_api_url.setter
    def service_api_url(self, service_api_url):
        """
        Sets the service_api_url of this Catalog.
        The REST front endpoint URL to the data catalog instance.


        :param service_api_url: The service_api_url of this Catalog.
        :type: str
        """
        self._service_api_url = service_api_url

    @property
    def service_console_url(self):
        """
        Gets the service_console_url of this Catalog.
        The console front endpoint URL to the data catalog instance.


        :return: The service_console_url of this Catalog.
        :rtype: str
        """
        return self._service_console_url

    @service_console_url.setter
    def service_console_url(self, service_console_url):
        """
        Sets the service_console_url of this Catalog.
        The console front endpoint URL to the data catalog instance.


        :param service_console_url: The service_console_url of this Catalog.
        :type: str
        """
        self._service_console_url = service_console_url

    @property
    def number_of_objects(self):
        """
        Gets the number_of_objects of this Catalog.
        The number of data objects added to the data catalog.
        Please see the data catalog documentation for further information on how this is calculated.


        :return: The number_of_objects of this Catalog.
        :rtype: int
        """
        return self._number_of_objects

    @number_of_objects.setter
    def number_of_objects(self, number_of_objects):
        """
        Sets the number_of_objects of this Catalog.
        The number of data objects added to the data catalog.
        Please see the data catalog documentation for further information on how this is calculated.


        :param number_of_objects: The number_of_objects of this Catalog.
        :type: int
        """
        self._number_of_objects = number_of_objects

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this Catalog.
        The current state of the data catalog resource.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Catalog.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Catalog.
        The current state of the data catalog resource.


        :param lifecycle_state: The lifecycle_state of this Catalog.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this Catalog.
        An message describing the current state in more detail.
        For example, it can be used to provide actionable information for a resource in 'Failed' state.


        :return: The lifecycle_details of this Catalog.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this Catalog.
        An message describing the current state in more detail.
        For example, it can be used to provide actionable information for a resource in 'Failed' state.


        :param lifecycle_details: The lifecycle_details of this Catalog.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Catalog.
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this Catalog.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Catalog.
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this Catalog.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Catalog.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this Catalog.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Catalog.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this Catalog.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def attached_catalog_private_endpoints(self):
        """
        Gets the attached_catalog_private_endpoints of this Catalog.
        The list of private reverse connection endpoints attached to the catalog


        :return: The attached_catalog_private_endpoints of this Catalog.
        :rtype: list[str]
        """
        return self._attached_catalog_private_endpoints

    @attached_catalog_private_endpoints.setter
    def attached_catalog_private_endpoints(self, attached_catalog_private_endpoints):
        """
        Sets the attached_catalog_private_endpoints of this Catalog.
        The list of private reverse connection endpoints attached to the catalog


        :param attached_catalog_private_endpoints: The attached_catalog_private_endpoints of this Catalog.
        :type: list[str]
        """
        self._attached_catalog_private_endpoints = attached_catalog_private_endpoints

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BadUserStateAuthenticateUserResult(object):
    """
    BadUserStateAuthenticateUserResult model.
    """

    #: A constant which can be used with the user_state property of a BadUserStateAuthenticateUserResult.
    #: This constant has a value of "USER_BLOCKED"
    USER_STATE_USER_BLOCKED = "USER_BLOCKED"

    #: A constant which can be used with the user_state property of a BadUserStateAuthenticateUserResult.
    #: This constant has a value of "USER_DISABLED"
    USER_STATE_USER_DISABLED = "USER_DISABLED"

    #: A constant which can be used with the user_state property of a BadUserStateAuthenticateUserResult.
    #: This constant has a value of "ONE_TIME_PASSWORD_EXPIRED"
    USER_STATE_ONE_TIME_PASSWORD_EXPIRED = "ONE_TIME_PASSWORD_EXPIRED"

    #: A constant which can be used with the user_state property of a BadUserStateAuthenticateUserResult.
    #: This constant has a value of "PASSWORD_INVALID"
    USER_STATE_PASSWORD_INVALID = "PASSWORD_INVALID"

    def __init__(self, **kwargs):
        """
        Initializes a new BadUserStateAuthenticateUserResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tenant_input:
            The value to assign to the tenant_input property of this BadUserStateAuthenticateUserResult.
        :type tenant_input: str

        :param user_input:
            The value to assign to the user_input property of this BadUserStateAuthenticateUserResult.
        :type user_input: str

        :param resolved_tenant_id:
            The value to assign to the resolved_tenant_id property of this BadUserStateAuthenticateUserResult.
        :type resolved_tenant_id: str

        :param resolved_user_id:
            The value to assign to the resolved_user_id property of this BadUserStateAuthenticateUserResult.
        :type resolved_user_id: str

        :param user_state:
            The value to assign to the user_state property of this BadUserStateAuthenticateUserResult.
            Allowed values for this property are: "USER_BLOCKED", "USER_DISABLED", "ONE_TIME_PASSWORD_EXPIRED", "PASSWORD_INVALID"
        :type user_state: str

        """
        self.swagger_types = {
            'tenant_input': 'str',
            'user_input': 'str',
            'resolved_tenant_id': 'str',
            'resolved_user_id': 'str',
            'user_state': 'str'
        }

        self.attribute_map = {
            'tenant_input': 'tenantInput',
            'user_input': 'userInput',
            'resolved_tenant_id': 'resolvedTenantId',
            'resolved_user_id': 'resolvedUserId',
            'user_state': 'userState'
        }

        self._tenant_input = None
        self._user_input = None
        self._resolved_tenant_id = None
        self._resolved_user_id = None
        self._user_state = None

    @property
    def tenant_input(self):
        """
        **[Required]** Gets the tenant_input of this BadUserStateAuthenticateUserResult.
        The tenant name.


        :return: The tenant_input of this BadUserStateAuthenticateUserResult.
        :rtype: str
        """
        return self._tenant_input

    @tenant_input.setter
    def tenant_input(self, tenant_input):
        """
        Sets the tenant_input of this BadUserStateAuthenticateUserResult.
        The tenant name.


        :param tenant_input: The tenant_input of this BadUserStateAuthenticateUserResult.
        :type: str
        """
        self._tenant_input = tenant_input

    @property
    def user_input(self):
        """
        **[Required]** Gets the user_input of this BadUserStateAuthenticateUserResult.
        The user name.


        :return: The user_input of this BadUserStateAuthenticateUserResult.
        :rtype: str
        """
        return self._user_input

    @user_input.setter
    def user_input(self, user_input):
        """
        Sets the user_input of this BadUserStateAuthenticateUserResult.
        The user name.


        :param user_input: The user_input of this BadUserStateAuthenticateUserResult.
        :type: str
        """
        self._user_input = user_input

    @property
    def resolved_tenant_id(self):
        """
        **[Required]** Gets the resolved_tenant_id of this BadUserStateAuthenticateUserResult.
        The resolved tenant id.


        :return: The resolved_tenant_id of this BadUserStateAuthenticateUserResult.
        :rtype: str
        """
        return self._resolved_tenant_id

    @resolved_tenant_id.setter
    def resolved_tenant_id(self, resolved_tenant_id):
        """
        Sets the resolved_tenant_id of this BadUserStateAuthenticateUserResult.
        The resolved tenant id.


        :param resolved_tenant_id: The resolved_tenant_id of this BadUserStateAuthenticateUserResult.
        :type: str
        """
        self._resolved_tenant_id = resolved_tenant_id

    @property
    def resolved_user_id(self):
        """
        **[Required]** Gets the resolved_user_id of this BadUserStateAuthenticateUserResult.
        The resolved user id.


        :return: The resolved_user_id of this BadUserStateAuthenticateUserResult.
        :rtype: str
        """
        return self._resolved_user_id

    @resolved_user_id.setter
    def resolved_user_id(self, resolved_user_id):
        """
        Sets the resolved_user_id of this BadUserStateAuthenticateUserResult.
        The resolved user id.


        :param resolved_user_id: The resolved_user_id of this BadUserStateAuthenticateUserResult.
        :type: str
        """
        self._resolved_user_id = resolved_user_id

    @property
    def user_state(self):
        """
        **[Required]** Gets the user_state of this BadUserStateAuthenticateUserResult.
        The bad user state.

        Allowed values for this property are: "USER_BLOCKED", "USER_DISABLED", "ONE_TIME_PASSWORD_EXPIRED", "PASSWORD_INVALID"


        :return: The user_state of this BadUserStateAuthenticateUserResult.
        :rtype: str
        """
        return self._user_state

    @user_state.setter
    def user_state(self, user_state):
        """
        Sets the user_state of this BadUserStateAuthenticateUserResult.
        The bad user state.


        :param user_state: The user_state of this BadUserStateAuthenticateUserResult.
        :type: str
        """
        allowed_values = ["USER_BLOCKED", "USER_DISABLED", "ONE_TIME_PASSWORD_EXPIRED", "PASSWORD_INVALID"]
        if not value_allowed_none_or_none_sentinel(user_state, allowed_values):
            raise ValueError(
                "Invalid value for `user_state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._user_state = user_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RepositoryRef(object):
    """
    Reference object with name and commit ID.
    """

    #: A constant which can be used with the ref_type property of a RepositoryRef.
    #: This constant has a value of "BRANCH"
    REF_TYPE_BRANCH = "BRANCH"

    #: A constant which can be used with the ref_type property of a RepositoryRef.
    #: This constant has a value of "TAG"
    REF_TYPE_TAG = "TAG"

    def __init__(self, **kwargs):
        """
        Initializes a new RepositoryRef object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.devops.models.RepositoryBranch`
        * :class:`~oci.devops.models.RepositoryTag`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ref_name:
            The value to assign to the ref_name property of this RepositoryRef.
        :type ref_name: str

        :param ref_type:
            The value to assign to the ref_type property of this RepositoryRef.
            Allowed values for this property are: "BRANCH", "TAG", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type ref_type: str

        :param full_ref_name:
            The value to assign to the full_ref_name property of this RepositoryRef.
        :type full_ref_name: str

        :param repository_id:
            The value to assign to the repository_id property of this RepositoryRef.
        :type repository_id: str

        """
        self.swagger_types = {
            'ref_name': 'str',
            'ref_type': 'str',
            'full_ref_name': 'str',
            'repository_id': 'str'
        }

        self.attribute_map = {
            'ref_name': 'refName',
            'ref_type': 'refType',
            'full_ref_name': 'fullRefName',
            'repository_id': 'repositoryId'
        }

        self._ref_name = None
        self._ref_type = None
        self._full_ref_name = None
        self._repository_id = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['refType']

        if type == 'BRANCH':
            return 'RepositoryBranch'

        if type == 'TAG':
            return 'RepositoryTag'
        else:
            return 'RepositoryRef'

    @property
    def ref_name(self):
        """
        **[Required]** Gets the ref_name of this RepositoryRef.
        Unique reference name inside a repository.


        :return: The ref_name of this RepositoryRef.
        :rtype: str
        """
        return self._ref_name

    @ref_name.setter
    def ref_name(self, ref_name):
        """
        Sets the ref_name of this RepositoryRef.
        Unique reference name inside a repository.


        :param ref_name: The ref_name of this RepositoryRef.
        :type: str
        """
        self._ref_name = ref_name

    @property
    def ref_type(self):
        """
        **[Required]** Gets the ref_type of this RepositoryRef.
        The type of reference (Branch or Tag).

        Allowed values for this property are: "BRANCH", "TAG", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The ref_type of this RepositoryRef.
        :rtype: str
        """
        return self._ref_type

    @ref_type.setter
    def ref_type(self, ref_type):
        """
        Sets the ref_type of this RepositoryRef.
        The type of reference (Branch or Tag).


        :param ref_type: The ref_type of this RepositoryRef.
        :type: str
        """
        allowed_values = ["BRANCH", "TAG"]
        if not value_allowed_none_or_none_sentinel(ref_type, allowed_values):
            ref_type = 'UNKNOWN_ENUM_VALUE'
        self._ref_type = ref_type

    @property
    def full_ref_name(self):
        """
        **[Required]** Gets the full_ref_name of this RepositoryRef.
        Unique full reference name inside a repository.


        :return: The full_ref_name of this RepositoryRef.
        :rtype: str
        """
        return self._full_ref_name

    @full_ref_name.setter
    def full_ref_name(self, full_ref_name):
        """
        Sets the full_ref_name of this RepositoryRef.
        Unique full reference name inside a repository.


        :param full_ref_name: The full_ref_name of this RepositoryRef.
        :type: str
        """
        self._full_ref_name = full_ref_name

    @property
    def repository_id(self):
        """
        **[Required]** Gets the repository_id of this RepositoryRef.
        The OCID of the repository containing the reference.


        :return: The repository_id of this RepositoryRef.
        :rtype: str
        """
        return self._repository_id

    @repository_id.setter
    def repository_id(self, repository_id):
        """
        Sets the repository_id of this RepositoryRef.
        The OCID of the repository containing the reference.


        :param repository_id: The repository_id of this RepositoryRef.
        :type: str
        """
        self._repository_id = repository_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiskGroupDetails(object):
    """
    Information about a diskgroup which includes diskgroup name and ASM name.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DiskGroupDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param diskgroup_name:
            The value to assign to the diskgroup_name property of this DiskGroupDetails.
        :type diskgroup_name: str

        :param asm_name:
            The value to assign to the asm_name property of this DiskGroupDetails.
        :type asm_name: str

        """
        self.swagger_types = {
            'diskgroup_name': 'str',
            'asm_name': 'str'
        }

        self.attribute_map = {
            'diskgroup_name': 'diskgroupName',
            'asm_name': 'asmName'
        }

        self._diskgroup_name = None
        self._asm_name = None

    @property
    def diskgroup_name(self):
        """
        **[Required]** Gets the diskgroup_name of this DiskGroupDetails.
        The diskgroup name.


        :return: The diskgroup_name of this DiskGroupDetails.
        :rtype: str
        """
        return self._diskgroup_name

    @diskgroup_name.setter
    def diskgroup_name(self, diskgroup_name):
        """
        Sets the diskgroup_name of this DiskGroupDetails.
        The diskgroup name.


        :param diskgroup_name: The diskgroup_name of this DiskGroupDetails.
        :type: str
        """
        self._diskgroup_name = diskgroup_name

    @property
    def asm_name(self):
        """
        **[Required]** Gets the asm_name of this DiskGroupDetails.
        The ASM name.


        :return: The asm_name of this DiskGroupDetails.
        :rtype: str
        """
        return self._asm_name

    @asm_name.setter
    def asm_name(self, asm_name):
        """
        Sets the asm_name of this DiskGroupDetails.
        The ASM name.


        :param asm_name: The asm_name of this DiskGroupDetails.
        :type: str
        """
        self._asm_name = asm_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectStorageBucketConfigDetails(object):
    """
    The details of the Object Storage bucket configured to store the certificate revocation list (CRL).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectStorageBucketConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param object_storage_namespace:
            The value to assign to the object_storage_namespace property of this ObjectStorageBucketConfigDetails.
        :type object_storage_namespace: str

        :param object_storage_bucket_name:
            The value to assign to the object_storage_bucket_name property of this ObjectStorageBucketConfigDetails.
        :type object_storage_bucket_name: str

        :param object_storage_object_name_format:
            The value to assign to the object_storage_object_name_format property of this ObjectStorageBucketConfigDetails.
        :type object_storage_object_name_format: str

        """
        self.swagger_types = {
            'object_storage_namespace': 'str',
            'object_storage_bucket_name': 'str',
            'object_storage_object_name_format': 'str'
        }

        self.attribute_map = {
            'object_storage_namespace': 'objectStorageNamespace',
            'object_storage_bucket_name': 'objectStorageBucketName',
            'object_storage_object_name_format': 'objectStorageObjectNameFormat'
        }

        self._object_storage_namespace = None
        self._object_storage_bucket_name = None
        self._object_storage_object_name_format = None

    @property
    def object_storage_namespace(self):
        """
        Gets the object_storage_namespace of this ObjectStorageBucketConfigDetails.
        The tenancy of the bucket where the CRL is stored.


        :return: The object_storage_namespace of this ObjectStorageBucketConfigDetails.
        :rtype: str
        """
        return self._object_storage_namespace

    @object_storage_namespace.setter
    def object_storage_namespace(self, object_storage_namespace):
        """
        Sets the object_storage_namespace of this ObjectStorageBucketConfigDetails.
        The tenancy of the bucket where the CRL is stored.


        :param object_storage_namespace: The object_storage_namespace of this ObjectStorageBucketConfigDetails.
        :type: str
        """
        self._object_storage_namespace = object_storage_namespace

    @property
    def object_storage_bucket_name(self):
        """
        **[Required]** Gets the object_storage_bucket_name of this ObjectStorageBucketConfigDetails.
        The name of the bucket where the CRL is stored.


        :return: The object_storage_bucket_name of this ObjectStorageBucketConfigDetails.
        :rtype: str
        """
        return self._object_storage_bucket_name

    @object_storage_bucket_name.setter
    def object_storage_bucket_name(self, object_storage_bucket_name):
        """
        Sets the object_storage_bucket_name of this ObjectStorageBucketConfigDetails.
        The name of the bucket where the CRL is stored.


        :param object_storage_bucket_name: The object_storage_bucket_name of this ObjectStorageBucketConfigDetails.
        :type: str
        """
        self._object_storage_bucket_name = object_storage_bucket_name

    @property
    def object_storage_object_name_format(self):
        """
        **[Required]** Gets the object_storage_object_name_format of this ObjectStorageBucketConfigDetails.
        The object name in the bucket where the CRL is stored, expressed using a format where the version number of the issuing CA is inserted as part of the Object Storage object name wherever you include a pair of curly braces. This versioning scheme helps avoid collisions when new CA versions are created. For example, myCrlFileIssuedFromCAVersion{}.crl becomes myCrlFileIssuedFromCAVersion2.crl for CA version 2.


        :return: The object_storage_object_name_format of this ObjectStorageBucketConfigDetails.
        :rtype: str
        """
        return self._object_storage_object_name_format

    @object_storage_object_name_format.setter
    def object_storage_object_name_format(self, object_storage_object_name_format):
        """
        Sets the object_storage_object_name_format of this ObjectStorageBucketConfigDetails.
        The object name in the bucket where the CRL is stored, expressed using a format where the version number of the issuing CA is inserted as part of the Object Storage object name wherever you include a pair of curly braces. This versioning scheme helps avoid collisions when new CA versions are created. For example, myCrlFileIssuedFromCAVersion{}.crl becomes myCrlFileIssuedFromCAVersion2.crl for CA version 2.


        :param object_storage_object_name_format: The object_storage_object_name_format of this ObjectStorageBucketConfigDetails.
        :type: str
        """
        self._object_storage_object_name_format = object_storage_object_name_format

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .commitment import Commitment
from .commitment_detail import CommitmentDetail
from .commitment_summary import CommitmentSummary
from .currency import Currency
from .product import Product
from .rate_card_summary import RateCardSummary
from .rate_card_tier import RateCardTier
from .subscribed_service_summary import SubscribedServiceSummary
from .subscription_product import SubscriptionProduct
from .subscription_summary import SubscriptionSummary

# Maps type names to classes for osub_subscription services.
osub_subscription_type_mapping = {
    "Commitment": Commitment,
    "CommitmentDetail": CommitmentDetail,
    "CommitmentSummary": CommitmentSummary,
    "Currency": Currency,
    "Product": Product,
    "RateCardSummary": RateCardSummary,
    "RateCardTier": RateCardTier,
    "SubscribedServiceSummary": SubscribedServiceSummary,
    "SubscriptionProduct": SubscriptionProduct,
    "SubscriptionSummary": SubscriptionSummary
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProtectionCapabilitySettings(object):
    """
    Settings for protection capabilities
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ProtectionCapabilitySettings object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param max_number_of_arguments:
            The value to assign to the max_number_of_arguments property of this ProtectionCapabilitySettings.
        :type max_number_of_arguments: int

        :param max_single_argument_length:
            The value to assign to the max_single_argument_length property of this ProtectionCapabilitySettings.
        :type max_single_argument_length: int

        :param max_total_argument_length:
            The value to assign to the max_total_argument_length property of this ProtectionCapabilitySettings.
        :type max_total_argument_length: int

        :param max_http_request_headers:
            The value to assign to the max_http_request_headers property of this ProtectionCapabilitySettings.
        :type max_http_request_headers: int

        :param max_http_request_header_length:
            The value to assign to the max_http_request_header_length property of this ProtectionCapabilitySettings.
        :type max_http_request_header_length: int

        :param allowed_http_methods:
            The value to assign to the allowed_http_methods property of this ProtectionCapabilitySettings.
        :type allowed_http_methods: list[str]

        """
        self.swagger_types = {
            'max_number_of_arguments': 'int',
            'max_single_argument_length': 'int',
            'max_total_argument_length': 'int',
            'max_http_request_headers': 'int',
            'max_http_request_header_length': 'int',
            'allowed_http_methods': 'list[str]'
        }

        self.attribute_map = {
            'max_number_of_arguments': 'maxNumberOfArguments',
            'max_single_argument_length': 'maxSingleArgumentLength',
            'max_total_argument_length': 'maxTotalArgumentLength',
            'max_http_request_headers': 'maxHttpRequestHeaders',
            'max_http_request_header_length': 'maxHttpRequestHeaderLength',
            'allowed_http_methods': 'allowedHttpMethods'
        }

        self._max_number_of_arguments = None
        self._max_single_argument_length = None
        self._max_total_argument_length = None
        self._max_http_request_headers = None
        self._max_http_request_header_length = None
        self._allowed_http_methods = None

    @property
    def max_number_of_arguments(self):
        """
        Gets the max_number_of_arguments of this ProtectionCapabilitySettings.
        Maximum number of arguments allowed. Used in protection capability 920380: Number of Arguments Limits.


        :return: The max_number_of_arguments of this ProtectionCapabilitySettings.
        :rtype: int
        """
        return self._max_number_of_arguments

    @max_number_of_arguments.setter
    def max_number_of_arguments(self, max_number_of_arguments):
        """
        Sets the max_number_of_arguments of this ProtectionCapabilitySettings.
        Maximum number of arguments allowed. Used in protection capability 920380: Number of Arguments Limits.


        :param max_number_of_arguments: The max_number_of_arguments of this ProtectionCapabilitySettings.
        :type: int
        """
        self._max_number_of_arguments = max_number_of_arguments

    @property
    def max_single_argument_length(self):
        """
        Gets the max_single_argument_length of this ProtectionCapabilitySettings.
        Maximum allowed length of a single argument. Used in protection capability 920370: Limit argument value length.


        :return: The max_single_argument_length of this ProtectionCapabilitySettings.
        :rtype: int
        """
        return self._max_single_argument_length

    @max_single_argument_length.setter
    def max_single_argument_length(self, max_single_argument_length):
        """
        Sets the max_single_argument_length of this ProtectionCapabilitySettings.
        Maximum allowed length of a single argument. Used in protection capability 920370: Limit argument value length.


        :param max_single_argument_length: The max_single_argument_length of this ProtectionCapabilitySettings.
        :type: int
        """
        self._max_single_argument_length = max_single_argument_length

    @property
    def max_total_argument_length(self):
        """
        Gets the max_total_argument_length of this ProtectionCapabilitySettings.
        Maximum allowed total length of all arguments. Used in protection capability 920390: Limit arguments total length.


        :return: The max_total_argument_length of this ProtectionCapabilitySettings.
        :rtype: int
        """
        return self._max_total_argument_length

    @max_total_argument_length.setter
    def max_total_argument_length(self, max_total_argument_length):
        """
        Sets the max_total_argument_length of this ProtectionCapabilitySettings.
        Maximum allowed total length of all arguments. Used in protection capability 920390: Limit arguments total length.


        :param max_total_argument_length: The max_total_argument_length of this ProtectionCapabilitySettings.
        :type: int
        """
        self._max_total_argument_length = max_total_argument_length

    @property
    def max_http_request_headers(self):
        """
        Gets the max_http_request_headers of this ProtectionCapabilitySettings.
        Maximum number of headers allowed in an HTTP request. Used in protection capability 9200014: Limit Number of Request Headers.


        :return: The max_http_request_headers of this ProtectionCapabilitySettings.
        :rtype: int
        """
        return self._max_http_request_headers

    @max_http_request_headers.setter
    def max_http_request_headers(self, max_http_request_headers):
        """
        Sets the max_http_request_headers of this ProtectionCapabilitySettings.
        Maximum number of headers allowed in an HTTP request. Used in protection capability 9200014: Limit Number of Request Headers.


        :param max_http_request_headers: The max_http_request_headers of this ProtectionCapabilitySettings.
        :type: int
        """
        self._max_http_request_headers = max_http_request_headers

    @property
    def max_http_request_header_length(self):
        """
        Gets the max_http_request_header_length of this ProtectionCapabilitySettings.
        Maximum allowed length of headers in an HTTP request. Used in protection capability: 9200024: Limit length of request header size.


        :return: The max_http_request_header_length of this ProtectionCapabilitySettings.
        :rtype: int
        """
        return self._max_http_request_header_length

    @max_http_request_header_length.setter
    def max_http_request_header_length(self, max_http_request_header_length):
        """
        Sets the max_http_request_header_length of this ProtectionCapabilitySettings.
        Maximum allowed length of headers in an HTTP request. Used in protection capability: 9200024: Limit length of request header size.


        :param max_http_request_header_length: The max_http_request_header_length of this ProtectionCapabilitySettings.
        :type: int
        """
        self._max_http_request_header_length = max_http_request_header_length

    @property
    def allowed_http_methods(self):
        """
        Gets the allowed_http_methods of this ProtectionCapabilitySettings.
        List of allowed HTTP methods. Each value as a RFC7230 formated token string.
        Used in protection capability 911100: Restrict HTTP Request Methods.


        :return: The allowed_http_methods of this ProtectionCapabilitySettings.
        :rtype: list[str]
        """
        return self._allowed_http_methods

    @allowed_http_methods.setter
    def allowed_http_methods(self, allowed_http_methods):
        """
        Sets the allowed_http_methods of this ProtectionCapabilitySettings.
        List of allowed HTTP methods. Each value as a RFC7230 formated token string.
        Used in protection capability 911100: Restrict HTTP Request Methods.


        :param allowed_http_methods: The allowed_http_methods of this ProtectionCapabilitySettings.
        :type: list[str]
        """
        self._allowed_http_methods = allowed_http_methods

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
